# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_ehr_employee_get_list import (
    GetEHREmployeeListReq,
    GetEHREmployeeListResp,
    _gen_get_ehr_employee_list_req,
)
from pylark.api_service_ehr_download_attachment import (
    DownloadEHRAttachmentsReq,
    DownloadEHRAttachmentsResp,
    _gen_download_ehr_attachments_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkEHRService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def get_ehr_employee_list(
        self, request: GetEHREmployeeListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetEHREmployeeListResp, Response]:
        return self.cli.raw_request(_gen_get_ehr_employee_list_req(request, options))

    def download_ehr_attachments(
        self, request: DownloadEHRAttachmentsReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadEHRAttachmentsResp, Response]:
        return self.cli.raw_request(_gen_download_ehr_attachments_req(request, options))



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetSheetConditionFormatReq(object):
    sheet_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 工作表ID，可以通过[获取表格元数据](https://open.feishu.cn/document/ukTMukTMukTM/uETMzUjLxEzM14SMxMTN)接口获取，多个ID用逗号分隔，如xxxID1,xxxID2
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)


@attr.s
class GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyleFont(object):
    bold: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})  # 加粗
    italic: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})  # 斜体


@attr.s
class GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyle(object):
    font: GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyleFont = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 字体样式
    text_decoration: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文本装饰 ，0 默认，1 下划线，2 删除线 ，3 下划线和删除线
    fore_color: str = attr.ib(default="", metadata={"req_type": "json"})  # 字体颜色
    back_color: str = attr.ib(default="", metadata={"req_type": "json"})  # 背景颜色


@attr.s
class GetSheetConditionFormatRespSheetConditionFormatConditionFormatAttrs(object):
    pass


@attr.s
class GetSheetConditionFormatRespSheetConditionFormatConditionFormat(object):
    cf_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 条件格式的id
    ranges: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 条件格式应用的范围，支持：sheetId（整表）；sheetId!1:2（整行）；sheetId!A:B（整列）；sheetId!A1:B2（普通范围）；sheetId!A1:C（应用至最后一行）。应用范围不能超过表格的行总数和列总数
    rule_type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 条件格式规则类型，目前只有7种：***containsBlanks（为空）、notContainsBlanks（不为空）、duplicateValues（重复值）、uniqueValues（唯一值）、cellIs（限定值范围）、containsText（包含内容）、timePeriod（日期）***
    attrs: typing.List[
        GetSheetConditionFormatRespSheetConditionFormatConditionFormatAttrs
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # rule_type对应的具体属性信息，详见 [条件格式指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/conditionformat/condition-format-guide)
    style: GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyle = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 条件格式样式，只支持以下样式


@attr.s
class GetSheetConditionFormatRespSheetConditionFormat(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheet的id
    condition_format: GetSheetConditionFormatRespSheetConditionFormatConditionFormat = (
        attr.ib(default=None, metadata={"req_type": "json"})
    )  # 一个条件格式的详细信息


@attr.s
class GetSheetConditionFormatResp(object):
    sheet_condition_formats: typing.List[
        GetSheetConditionFormatRespSheetConditionFormat
    ] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 表格的条件格式信息


def _gen_get_sheet_condition_format_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetSheetConditionFormatResp,
        scope="Drive",
        api="GetSheetConditionFormat",
        method="GET",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/condition_formats",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_contact_user_create import (
    CreateUserReq,
    CreateUserResp,
    _gen_create_user_req,
)
from pylark.api_service_contact_user_delete import (
    DeleteUserReq,
    DeleteUserResp,
    _gen_delete_user_req,
)
from pylark.api_service_contact_user_get import (
    GetUserReq,
    GetUserResp,
    _gen_get_user_req,
)
from pylark.api_service_contact_user_get_batch import (
    BatchGetUserReq,
    BatchGetUserResp,
    _gen_batch_get_user_req,
)
from pylark.api_service_contact_user_get_batch_by_id import (
    BatchGetUserByIDReq,
    BatchGetUserByIDResp,
    _gen_batch_get_user_by_id_req,
)
from pylark.api_service_contact_user_get_list import (
    GetUserListReq,
    GetUserListResp,
    _gen_get_user_list_req,
)
from pylark.api_service_contact_user_update_patch import (
    UpdateUserPatchReq,
    UpdateUserPatchResp,
    _gen_update_user_patch_req,
)
from pylark.api_service_contact_user_update import (
    UpdateUserReq,
    UpdateUserResp,
    _gen_update_user_req,
)
from pylark.api_service_contact_department_create import (
    CreateDepartmentReq,
    CreateDepartmentResp,
    _gen_create_department_req,
)
from pylark.api_service_contact_department_get import (
    GetDepartmentReq,
    GetDepartmentResp,
    _gen_get_department_req,
)
from pylark.api_service_contact_department_get_list import (
    GetDepartmentListReq,
    GetDepartmentListResp,
    _gen_get_department_list_req,
)
from pylark.api_service_contact_department_get_parent import (
    GetParentDepartmentReq,
    GetParentDepartmentResp,
    _gen_get_parent_department_req,
)
from pylark.api_service_contact_department_search import (
    SearchDepartmentReq,
    SearchDepartmentResp,
    _gen_search_department_req,
)
from pylark.api_service_contact_department_update_patch import (
    UpdateDepartmentPatchReq,
    UpdateDepartmentPatchResp,
    _gen_update_department_patch_req,
)
from pylark.api_service_contact_department_update import (
    UpdateDepartmentReq,
    UpdateDepartmentResp,
    _gen_update_department_req,
)
from pylark.api_service_contact_department_delete import (
    DeleteDepartmentReq,
    DeleteDepartmentResp,
    _gen_delete_department_req,
)
from pylark.api_service_contact_employee_type_enums_list import (
    GetEmployeeTypeEnumListReq,
    GetEmployeeTypeEnumListResp,
    _gen_get_employee_type_enum_list_req,
)
from pylark.api_service_contact_employee_type_enums_update import (
    UpdateEmployeeTypeEnumPatchReq,
    UpdateEmployeeTypeEnumPatchResp,
    _gen_update_employee_type_enum_patch_req,
)
from pylark.api_service_contact_employee_type_enums_delete import (
    DeleteEmployeeTypeEnumReq,
    DeleteEmployeeTypeEnumResp,
    _gen_delete_employee_type_enum_req,
)
from pylark.api_service_contact_employee_type_enums_create import (
    CreateEmployeeTypeEnumReq,
    CreateEmployeeTypeEnumResp,
    _gen_create_employee_type_enum_req,
)
from pylark.api_service_contact_custom_attr_list import (
    GetContactCustomAttrListReq,
    GetContactCustomAttrListResp,
    _gen_get_contact_custom_attr_list_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkContactService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def create_user(
        self, request: CreateUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateUserResp, Response]:
        return self.cli.raw_request(_gen_create_user_req(request, options))

    def delete_user(
        self, request: DeleteUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteUserResp, Response]:
        return self.cli.raw_request(_gen_delete_user_req(request, options))

    def get_user(
        self, request: GetUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetUserResp, Response]:
        return self.cli.raw_request(_gen_get_user_req(request, options))

    def batch_get_user(
        self, request: BatchGetUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetUserResp, Response]:
        return self.cli.raw_request(_gen_batch_get_user_req(request, options))

    def batch_get_user_by_id(
        self, request: BatchGetUserByIDReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetUserByIDResp, Response]:
        return self.cli.raw_request(_gen_batch_get_user_by_id_req(request, options))

    def get_user_list(
        self, request: GetUserListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetUserListResp, Response]:
        return self.cli.raw_request(_gen_get_user_list_req(request, options))

    def update_user_patch(
        self, request: UpdateUserPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateUserPatchResp, Response]:
        return self.cli.raw_request(_gen_update_user_patch_req(request, options))

    def update_user(
        self, request: UpdateUserReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateUserResp, Response]:
        return self.cli.raw_request(_gen_update_user_req(request, options))

    def create_department(
        self, request: CreateDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDepartmentResp, Response]:
        return self.cli.raw_request(_gen_create_department_req(request, options))

    def get_department(
        self, request: GetDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDepartmentResp, Response]:
        return self.cli.raw_request(_gen_get_department_req(request, options))

    def get_department_list(
        self, request: GetDepartmentListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDepartmentListResp, Response]:
        return self.cli.raw_request(_gen_get_department_list_req(request, options))

    def get_parent_department(
        self, request: GetParentDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetParentDepartmentResp, Response]:
        return self.cli.raw_request(_gen_get_parent_department_req(request, options))

    def search_department(
        self, request: SearchDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchDepartmentResp, Response]:
        return self.cli.raw_request(_gen_search_department_req(request, options))

    def update_department_patch(
        self, request: UpdateDepartmentPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDepartmentPatchResp, Response]:
        return self.cli.raw_request(_gen_update_department_patch_req(request, options))

    def update_department(
        self, request: UpdateDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDepartmentResp, Response]:
        return self.cli.raw_request(_gen_update_department_req(request, options))

    def delete_department(
        self, request: DeleteDepartmentReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteDepartmentResp, Response]:
        return self.cli.raw_request(_gen_delete_department_req(request, options))

    def get_employee_type_enum_list(
        self, request: GetEmployeeTypeEnumListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetEmployeeTypeEnumListResp, Response]:
        return self.cli.raw_request(
            _gen_get_employee_type_enum_list_req(request, options)
        )

    def update_employee_type_enum_patch(
        self, request: UpdateEmployeeTypeEnumPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateEmployeeTypeEnumPatchResp, Response]:
        return self.cli.raw_request(
            _gen_update_employee_type_enum_patch_req(request, options)
        )

    def delete_employee_type_enum(
        self, request: DeleteEmployeeTypeEnumReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteEmployeeTypeEnumResp, Response]:
        return self.cli.raw_request(
            _gen_delete_employee_type_enum_req(request, options)
        )

    def create_employee_type_enum(
        self, request: CreateEmployeeTypeEnumReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateEmployeeTypeEnumResp, Response]:
        return self.cli.raw_request(
            _gen_create_employee_type_enum_req(request, options)
        )

    def get_contact_custom_attr_list(
        self, request: GetContactCustomAttrListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetContactCustomAttrListResp, Response]:
        return self.cli.raw_request(
            _gen_get_contact_custom_attr_list_req(request, options)
        )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class RecognizeBasicImageReq(object):
    image: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # base64 后的图片数据, 示例值："base64后的图片二进制数据"


@attr.s
class RecognizeBasicImageResp(object):
    text_list: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 按区域识别，返回文本列表


def _gen_recognize_basic_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=RecognizeBasicImageResp,
        scope="AI",
        api="RecognizeBasicImage",
        method="POST",
        url="https://open.feishu.cn/open-apis/optical_char_recognition/v1/image/basic_recognize",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateMessageReq(object):
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待更新的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"
    content: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 消息内容 json 格式，[发送消息 content 说明](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/im-v1/message/create_json)，参考文档中的卡片格式|, 示例值："参考链接"


@attr.s
class UpdateMessageResp(object):
    pass


def _gen_update_message_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateMessageResp,
        scope="Message",
        api="UpdateMessage",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateChatReqMembershipApproval(object):
    pass


@attr.s
class CreateChatReqLeaveMessageVisibility(object):
    pass


@attr.s
class CreateChatReqJoinMessageVisibility(object):
    pass


@attr.s
class CreateChatReqChatType(object):
    pass


@attr.s
class CreateChatReqI18nNames(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名, 示例值："群聊"
    en_us: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 英文名, 示例值："group chat"
    ja_jp: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 日文名, 示例值："グループチャット"


@attr.s
class CreateChatReq(object):
    avatar: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群头像对应的 Image Key，可通过[上传图片](https://open.feishu.cn/document/uAjLw4CM/ukTMukTMukTM/reference/im-v1/image/create)获取（注意：上传图片的 [image_type] 需要指定为 [avatar]）, 示例值："default-avatar_44ae0ca3-e140-494b-956f-78091e348435"
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 群名称, 示例值："测试群名称"
    description: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群描述, 示例值："测试群描述"
    i18n_names: CreateChatReqI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群国际化名称
    chat_mode: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 群模式(group), 示例值："group"
    chat_type: CreateChatReqChatType = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群类型(private/public), 示例值："private"
    join_message_visibility: CreateChatReqJoinMessageVisibility = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 入群消息可见性(only_owner/all_members/not_anyone), 示例值："all_members"
    leave_message_visibility: CreateChatReqLeaveMessageVisibility = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 出群消息可见性(only_owner/all_members/not_anyone), 示例值："all_members"
    membership_approval: CreateChatReqMembershipApproval = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 加群审批(no_approval_required/approval_required), 示例值："no_approval_required"


@attr.s
class CreateChatRespModerationPermission(object):
    pass


@attr.s
class CreateChatRespMembershipApproval(object):
    pass


@attr.s
class CreateChatRespLeaveMessageVisibility(object):
    pass


@attr.s
class CreateChatRespJoinMessageVisibility(object):
    pass


@attr.s
class CreateChatRespChatType(object):
    pass


@attr.s
class CreateChatRespEditPermission(object):
    pass


@attr.s
class CreateChatRespAtAllPermission(object):
    pass


@attr.s
class CreateChatRespShareCardPermission(object):
    pass


@attr.s
class CreateChatRespAddMemberPermission(object):
    pass


@attr.s
class CreateChatRespI18nNames(object):
    zh_cn: str = attr.ib(default="", metadata={"req_type": "json"})  # 中文名
    en_us: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名
    ja_jp: str = attr.ib(default="", metadata={"req_type": "json"})  # 日文名


@attr.s
class CreateChatResp(object):
    chat_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 群 ID
    avatar: str = attr.ib(default="", metadata={"req_type": "json"})  # 群头像 URL
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 群名称
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 群描述
    i18n_names: CreateChatRespI18nNames = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 群国际化名称
    add_member_permission: CreateChatRespAddMemberPermission = attr.ib(
        factory=lambda: CreateChatRespAddMemberPermission(),
        metadata={"req_type": "json"},
    )  # 加 user/bot 入群权限(all_members/only_owner)
    share_card_permission: CreateChatRespShareCardPermission = attr.ib(
        factory=lambda: CreateChatRespShareCardPermission(),
        metadata={"req_type": "json"},
    )  # 群分享权限(allowed/not_allowed)
    at_all_permission: CreateChatRespAtAllPermission = attr.ib(
        factory=lambda: CreateChatRespAtAllPermission(), metadata={"req_type": "json"}
    )  # at 所有人权限(all_members/only_owner)
    edit_permission: CreateChatRespEditPermission = attr.ib(
        factory=lambda: CreateChatRespEditPermission(), metadata={"req_type": "json"}
    )  # 群编辑权限(all_members/only_owner)
    chat_mode: str = attr.ib(default="", metadata={"req_type": "json"})  # 群模式(group)
    chat_type: CreateChatRespChatType = attr.ib(
        factory=lambda: CreateChatRespChatType(), metadata={"req_type": "json"}
    )  # 群类型(private/public)
    chat_tag: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 优先级最高的一个群 tag（inner/tenant/department/edu/meeting/customer_service）
    join_message_visibility: CreateChatRespJoinMessageVisibility = attr.ib(
        factory=lambda: CreateChatRespJoinMessageVisibility(),
        metadata={"req_type": "json"},
    )  # 入群消息可见性(only_owner/all_members/not_anyone)
    leave_message_visibility: CreateChatRespLeaveMessageVisibility = attr.ib(
        factory=lambda: CreateChatRespLeaveMessageVisibility(),
        metadata={"req_type": "json"},
    )  # 出群消息可见性(only_owner/all_members/not_anyone)
    membership_approval: CreateChatRespMembershipApproval = attr.ib(
        factory=lambda: CreateChatRespMembershipApproval(),
        metadata={"req_type": "json"},
    )  # 加群审批(no_approval_required/approval_required)
    moderation_permission: CreateChatRespModerationPermission = attr.ib(
        factory=lambda: CreateChatRespModerationPermission(),
        metadata={"req_type": "json"},
    )  # 发言权限(all_members/only_owner/moderator_list)


def _gen_create_chat_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateChatResp,
        scope="Chat",
        api="CreateChat",
        method="POST",
        url="https://open.feishu.cn/open-apis/im/v1/chats",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetAttendanceShiftByNameReq(object):
    shift_name: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 班次名称，示例值："早班"


@attr.s
class GetAttendanceShiftByNameRespRestTimeRule(object):
    rest_begin_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 休息开始时间
    rest_end_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 休息结束时间


@attr.s
class GetAttendanceShiftByNameRespLateOffLateOnRule(object):
    late_off_minutes: int = attr.ib(default=0, metadata={"req_type": "json"})  # 晚走多长时间
    late_on_minutes: int = attr.ib(default=0, metadata={"req_type": "json"})  # 晚到多长时间


@attr.s
class GetAttendanceShiftByNameRespPunchTimeRule(object):
    on_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 上班时间
    off_time: str = attr.ib(default="", metadata={"req_type": "json"})  # 下班时间
    late_minutes_as_late: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 晚到多长时间记为迟到
    late_minutes_as_lack: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 晚到多长时间记为缺卡
    on_advance_minutes: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 最早可提前多长时间打上班卡
    early_minutes_as_early: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 早走多长时间记为早退
    early_minutes_as_lack: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 早走多长时间记为缺卡
    off_delay_minutes: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 最晚可延后多长时间打下班卡


@attr.s
class GetAttendanceShiftByNameResp(object):
    shift_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次 ID
    shift_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 班次名称
    punch_times: int = attr.ib(default=0, metadata={"req_type": "json"})  # 打卡次数
    is_flexible: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否弹性打卡
    flexible_minutes: int = attr.ib(default=0, metadata={"req_type": "json"})  # 弹性打卡时间
    no_need_off: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否下班免打卡
    punch_time_rule: GetAttendanceShiftByNameRespPunchTimeRule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 打卡规则
    late_off_late_on_rule: GetAttendanceShiftByNameRespLateOffLateOnRule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 晚走晚到规则
    rest_time_rule: GetAttendanceShiftByNameRespRestTimeRule = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 休息时间规则


def _gen_get_attendance_shift_by_name_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetAttendanceShiftByNameResp,
        scope="Attendance",
        api="GetAttendanceShiftByName",
        method="POST",
        url="https://open.feishu.cn/open-apis/attendance/v1/shifts/query",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetApplicationAppVisibilityReq(object):
    app_id: str = attr.ib(default="", metadata={"req_type": "query"})  # 目标应用的 ID
    user_page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页拉取用户列表起始位置标示，不填表示从头开始
    user_page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 本次拉取用户列表最大个数(最大值 1000 ，0 自动最大个数 )


@attr.s
class GetApplicationAppVisibilityRespUsers(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的 user_id，只返回给申请了 user_id 权限的企业自建应用
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id


@attr.s
class GetApplicationAppVisibilityRespDepartments(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 自定义 department_id


@attr.s
class GetApplicationAppVisibilityResp(object):
    departments: GetApplicationAppVisibilityRespDepartments = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可用部门列表
    users: GetApplicationAppVisibilityRespUsers = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 可用用户列表（仅包含单独设置的用户，可用部门、用户组中的用户未展开）
    is_visible_to_all: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 是否全员可见，1：是，0：否
    has_more_users: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 是否还有更多可见用户，1：是，0：否
    user_page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 拉取下一页用户列表时使用的 user_page_token


def _gen_get_application_app_visibility_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetApplicationAppVisibilityResp,
        scope="Application",
        api="GetApplicationAppVisibility",
        method="GET",
        url="https://open.feishu.cn/open-apis/application/v2/app/visibility",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetDriveFileStatisticsReqFileType(object):
    pass


@attr.s
class GetDriveFileStatisticsReq(object):
    file_type: GetDriveFileStatisticsReqFileType = attr.ib(
        factory=lambda: GetDriveFileStatisticsReqFileType(),
        metadata={"req_type": "query"},
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `mindnote`：思维笔记, `bitable`：多维表格, `wiki`：知识库, `file`：文件
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文件 token, 示例值："doccnRs*******"


@attr.s
class GetDriveFileStatisticsRespStatistics(object):
    uv: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件历史访问人数，同一用户（user_id）多次访问按一次计算。
    pv: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件历史访问次数，同一用户（user_id）多次访问按多次计算。（注：同一用户相邻两次访问间隔在半小时内视为一次访问）
    like_count: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 文件历史点赞总数，若对应的文档类型不支持点赞，返回 -1
    timestamp: int = attr.ib(default=0, metadata={"req_type": "json"})  # 时间戳（秒）


@attr.s
class GetDriveFileStatisticsRespFileType(object):
    pass


@attr.s
class GetDriveFileStatisticsResp(object):
    file_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 文件 token
    file_type: GetDriveFileStatisticsRespFileType = attr.ib(
        factory=lambda: GetDriveFileStatisticsRespFileType(),
        metadata={"req_type": "json"},
    )  # 文件类型
    statistics: GetDriveFileStatisticsRespStatistics = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文件统计信息


def _gen_get_drive_file_statistics_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetDriveFileStatisticsResp,
        scope="Drive",
        api="GetDriveFileStatistics",
        method="GET",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/statistics",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateDriveCommentReqReplyListReplyContentElementPerson(object):
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 at联系人, 示例值："ou_cc19b2bfb93f8a44db4b4d6eab*****"


@attr.s
class CreateDriveCommentReqReplyListReplyContentElementDocsLink(object):
    url: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 at云文档, 示例值："https://bytedance.feishu.cn/docs/doccnHh7U87HOFpii5u5G*****"


@attr.s
class CreateDriveCommentReqReplyListReplyContentElementTextRun(object):
    text: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复 普通文本, 示例值："comment text"


@attr.s
class CreateDriveCommentReqReplyListReplyContentElement(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复的内容元素, 示例值："text_run", 可选值有: `text_run`：普通文本, `docs_link`：at 云文档链接, `person`：at 联系人
    text_run: CreateDriveCommentReqReplyListReplyContentElementTextRun = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    docs_link: CreateDriveCommentReqReplyListReplyContentElementDocsLink = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    person: CreateDriveCommentReqReplyListReplyContentElementPerson = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容


@attr.s
class CreateDriveCommentReqReplyListReplyContent(object):
    elements: typing.List[CreateDriveCommentReqReplyListReplyContentElement] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复的内容


@attr.s
class CreateDriveCommentReqReplyListReply(object):
    reply_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复ID, 示例值："6916106822734594568"
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户ID, 示例值："ou_cc19b2bfb93f8a44db4b4d6eab2*****"
    create_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 创建时间, 示例值：1610281603
    update_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 更新时间, 示例值：1610281603
    content: CreateDriveCommentReqReplyListReplyContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 回复内容


@attr.s
class CreateDriveCommentReqReplyList(object):
    replies: typing.List[CreateDriveCommentReqReplyListReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复列表


@attr.s
class CreateDriveCommentReqUserIDType(object):
    pass


@attr.s
class CreateDriveCommentReqFileType(object):
    pass


@attr.s
class CreateDriveCommentReq(object):
    file_type: CreateDriveCommentReqFileType = attr.ib(
        factory=lambda: CreateDriveCommentReqFileType(), metadata={"req_type": "query"}
    )  # 文档类型, 示例值："doc", 可选值有: `doc`：文档, `sheet`：表格, `file`：文件
    user_id_type: CreateDriveCommentReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    file_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 文档token, 示例值："doccnGp4UK1UskrOEJwBXd3****"
    comment_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 评论ID, 示例值："6916106822734578184"
    user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户ID, 示例值："ou_cc19b2bfb93f8a44db4b4d6eab*****"
    create_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 创建时间, 示例值：1610281603
    update_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 更新时间, 示例值：1610281603
    is_solved: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 是否已解决, 示例值：false
    solved_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 解决评论时间, 示例值：1610281603
    solver_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 解决评论者的用户ID, 示例值："null"
    reply_list: CreateDriveCommentReqReplyList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 评论里的回复列表


@attr.s
class CreateDriveCommentRespReplyListReplyContentElementPerson(object):
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at联系人


@attr.s
class CreateDriveCommentRespReplyListReplyContentElementDocsLink(object):
    url: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 at云文档


@attr.s
class CreateDriveCommentRespReplyListReplyContentElementTextRun(object):
    text: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复 普通文本


@attr.s
class CreateDriveCommentRespReplyListReplyContentElement(object):
    type: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 回复的内容元素, 可选值有: `text_run`：普通文本, `docs_link`：at 云文档链接, `person`：at 联系人
    text_run: CreateDriveCommentRespReplyListReplyContentElementTextRun = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    docs_link: CreateDriveCommentRespReplyListReplyContentElementDocsLink = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容
    person: CreateDriveCommentRespReplyListReplyContentElementPerson = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 文本内容


@attr.s
class CreateDriveCommentRespReplyListReplyContent(object):
    elements: typing.List[CreateDriveCommentRespReplyListReplyContentElement] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复的内容


@attr.s
class CreateDriveCommentRespReplyListReply(object):
    reply_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 回复ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    content: CreateDriveCommentRespReplyListReplyContent = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 回复内容


@attr.s
class CreateDriveCommentRespReplyList(object):
    replies: typing.List[CreateDriveCommentRespReplyListReply] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 回复列表


@attr.s
class CreateDriveCommentResp(object):
    comment_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 评论ID
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户ID
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    is_solved: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否已解决
    solved_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 解决评论时间
    solver_user_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 解决评论者的用户ID
    reply_list: CreateDriveCommentRespReplyList = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 评论里的回复列表


def _gen_create_drive_comment_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateDriveCommentResp,
        scope="Drive",
        api="CreateDriveComment",
        method="POST",
        url="https://open.feishu.cn/open-apis/drive/v1/files/:file_token/comments",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



class PyLarkError(Exception):
    def __init__(self, scope: str, func: str, code: int, msg: str):
        super().__init__(
            f"pylark error, scope={scope}, func={func}, code={code}, msg={msg}"
        )

        self.scope = scope
        self.func = func
        self.code = code
        self.msg = msg



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHelpdeskAgentSkillListReq(object):
    pass


@attr.s
class GetHelpdeskAgentSkillListRespAgentSkill(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 技能id
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 技能名
    agent_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 具有此技能的客服ids
    is_default: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 默认技能


@attr.s
class GetHelpdeskAgentSkillListResp(object):
    agent_skills: typing.List[GetHelpdeskAgentSkillListRespAgentSkill] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 客服技能列表


def _gen_get_helpdesk_agent_skill_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHelpdeskAgentSkillListResp,
        scope="Helpdesk",
        api="GetHelpdeskAgentSkillList",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/agent_skills",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class BatchGetUserReq(object):
    employee_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 支持通过 open_id 或者 employee_id 查询用户信息，不支持混合两种 ID 进行查询，单次请求支持的最大用户数量为100
    open_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "query"}
    )  # 支持通过 open_id 或者 employee_id 查询用户信息，不支持混合两种 ID 进行查询，单次请求支持的最大用户数量为100


@attr.s
class BatchGetUserRespUserInfoCustomAttr(object):
    pass


@attr.s
class BatchGetUserRespUserInfo(object):
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名
    name_py: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户名拼音
    en_name: str = attr.ib(default="", metadata={"req_type": "json"})  # 英文名
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户的 employee_id，申请了"获取用户 user_id"权限的应用返回该字段
    employee_no: str = attr.ib(default="", metadata={"req_type": "json"})  # 工号
    open_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 open_id
    union_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户的 union_id
    status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 用户状态，bit0(最低位): 1冻结，0未冻结；bit1:1离职，0在职；bit2:1未激活，0已激活
    employee_type: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 员工类型。1:正式员工；2:实习生；3:外包；4:劳务；5:顾问
    avatar_72: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像，72*72px
    avatar_240: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户头像，240*240px
    avatar_640: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户头像，640*640px
    avatar_url: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户头像，原始大小
    gender: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 性别，未设置不返回该字段。1:男；2:女
    email: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户邮箱地址，已申请"获取用户邮箱"权限返回该字段
    mobile: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户手机号，已申请"获取用户手机号"权限的企业自建应用返回该字段
    description: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户个人签名
    country: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户所在国家
    city: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户所在城市
    work_station: str = attr.ib(default="", metadata={"req_type": "json"})  # 工位
    is_tenant_manager: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否是企业超级管理员
    join_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 入职时间，未设置不返回该字段
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    leader_employee_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户直接领导的 employee_id，企业自建应用返回，应用商店应用申请了 employee_id 权限时才返回
    leader_open_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户直接领导的 open_id
    leader_union_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 用户直接领导的 union_id
    departments: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户所在部门自定义 ID列表，用户可能同时存在于多个部门
    open_departments: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户所在部门 openID 列表，用户可能同时存在于多个部门
    custom_attrs: BatchGetUserRespUserInfoCustomAttr = attr.ib(
        factory=lambda: BatchGetUserRespUserInfoCustomAttr(),
        metadata={"req_type": "json"},
    )  # 用户的自定义属性信息。<br>该字段返回的每一个属性包括自定义属性 ID 和自定义属性值。 <br>企业开放了自定义用户属性且为该用户设置了自定义属性的值，才会返回该字段


@attr.s
class BatchGetUserResp(object):
    user_infos: typing.List[BatchGetUserRespUserInfo] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 用户信息


def _gen_batch_get_user_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=BatchGetUserResp,
        scope="Contact",
        api="BatchGetUser",
        method="GET",
        url="https://open.feishu.cn/open-apis/contact/v1/user/batch_get",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class SearchHelpdeskFAQReq(object):
    query: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 搜索query, 示例值："点餐"
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："6936004780707807251"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`


@attr.s
class SearchHelpdeskFAQRespItemCategorie(object):
    category_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库分类ID
    id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 知识库分类ID，（旧版，请使用category_id）
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 名称
    parent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 父知识库分类ID
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    language: str = attr.ib(default="", metadata={"req_type": "json"})  # 语言


@attr.s
class SearchHelpdeskFAQRespItem(object):
    faq_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库ID
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 知识库旧版ID，请使用faq_id
    helpdesk_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 服务台ID
    question: str = attr.ib(default="", metadata={"req_type": "json"})  # 问题
    answer: str = attr.ib(default="", metadata={"req_type": "json"})  # 答案
    answer_richtext: str = attr.ib(default="", metadata={"req_type": "json"})  # 富文本答案
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    update_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 修改时间
    categories: typing.List[SearchHelpdeskFAQRespItemCategorie] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 分类
    tags: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 关联词列表
    expire_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 失效时间


@attr.s
class SearchHelpdeskFAQResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[SearchHelpdeskFAQRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 知识库列表


def _gen_search_helpdesk_faq_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=SearchHelpdeskFAQResp,
        scope="Helpdesk",
        api="SearchHelpdeskFAQ",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/faqs/search",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateHireEmployeeReqOverboardInfo(object):
    actual_overboard_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际离职日期, 示例值：1637596800000
    overboard_note: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 离职原因, 示例值："职业发展考虑"


@attr.s
class UpdateHireEmployeeReqConversionInfo(object):
    actual_conversion_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际转正日期, 示例值：1637596800000


@attr.s
class UpdateHireEmployeeReq(object):
    employee_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 员工ID, 示例值："123"
    operation: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 修改状态操作, 示例值：1, 可选值有: `1`：转正, `2`：离职
    conversion_info: UpdateHireEmployeeReqConversionInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 转正信息
    overboard_info: UpdateHireEmployeeReqOverboardInfo = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 离职信息


@attr.s
class UpdateHireEmployeeRespEmployee(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # 员工ID
    application_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递ID
    onboard_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 入职状态, 可选值有: `1`：已入职, `2`：已离职
    conversion_status: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 转正状态, 可选值有: `1`：未转正, `2`：已转正
    onboard_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 实际入职时间
    expected_conversion_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 预期转正时间
    actual_conversion_time: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 实际转正时间
    overboard_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 离职时间
    overboard_note: str = attr.ib(default="", metadata={"req_type": "json"})  # 离职原因


@attr.s
class UpdateHireEmployeeResp(object):
    employee: UpdateHireEmployeeRespEmployee = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 员工信息


def _gen_update_hire_employee_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateHireEmployeeResp,
        scope="Hire",
        api="UpdateHireEmployee",
        method="PATCH",
        url="https://open.feishu.cn/open-apis/hire/v1/employees/:employee_id",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetHireNoteListReqUserIDType(object):
    pass


@attr.s
class GetHireNoteListReq(object):
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 每页限制, 每页最大不超过100, 示例值：10
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 查询游标, 由上一页结果返回, 第一页不传, 示例值："1"
    talent_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 人才ID, 示例值："6916472453069883661"
    user_id_type: GetHireNoteListReqUserIDType = attr.ib(
        default=None, metadata={"req_type": "query"}
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid


@attr.s
class GetHireNoteListRespItem(object):
    id: str = attr.ib(default="", metadata={"req_type": "json"})  # ID备注
    talent_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 人才ID
    application_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 投递ID
    is_private: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否私密
    create_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 创建时间
    modify_time: int = attr.ib(default=0, metadata={"req_type": "json"})  # 更新时间
    creator_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 创建人ID
    content: str = attr.ib(default="", metadata={"req_type": "json"})  # 内容


@attr.s
class GetHireNoteListResp(object):
    items: typing.List[GetHireNoteListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 备注数据列表
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有下一页数据
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 游标, 翻下一页数据时使用


def _gen_get_hire_note_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetHireNoteListResp,
        scope="Hire",
        api="GetHireNoteList",
        method="GET",
        url="https://open.feishu.cn/open-apis/hire/v1/notes",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_helpdesk_start_service import (
    StartHelpdeskServiceReq,
    StartHelpdeskServiceResp,
    _gen_start_helpdesk_service_req,
)
from pylark.api_service_helpdesk_ticket_get import (
    GetHelpdeskTicketReq,
    GetHelpdeskTicketResp,
    _gen_get_helpdesk_ticket_req,
)
from pylark.api_service_helpdesk_ticket_update import (
    UpdateHelpdeskTicketReq,
    UpdateHelpdeskTicketResp,
    _gen_update_helpdesk_ticket_req,
)
from pylark.api_service_helpdesk_ticket_get_list import (
    GetHelpdeskTicketListReq,
    GetHelpdeskTicketListResp,
    _gen_get_helpdesk_ticket_list_req,
)
from pylark.api_service_helpdesk_ticket_image_download import (
    DownloadHelpdeskTicketImageReq,
    DownloadHelpdeskTicketImageResp,
    _gen_download_helpdesk_ticket_image_req,
)
from pylark.api_service_helpdesk_ticket_answer_user_query import (
    AnswerHelpdeskTicketUserQueryReq,
    AnswerHelpdeskTicketUserQueryResp,
    _gen_answer_helpdesk_ticket_user_query_req,
)
from pylark.api_service_helpdesk_ticket_message_get_list import (
    GetHelpdeskTicketMessageListReq,
    GetHelpdeskTicketMessageListResp,
    _gen_get_helpdesk_ticket_message_list_req,
)
from pylark.api_service_helpdesk_ticket_message_send import (
    SendHelpdeskTicketMessageReq,
    SendHelpdeskTicketMessageResp,
    _gen_send_helpdesk_ticket_message_req,
)
from pylark.api_service_helpdesk_ticket_customized_field_get_list import (
    GetHelpdeskTicketCustomizedFieldListReq,
    GetHelpdeskTicketCustomizedFieldListResp,
    _gen_get_helpdesk_ticket_customized_field_list_req,
)
from pylark.api_service_helpdesk_ticket_customized_field_delete import (
    DeleteHelpdeskTicketCustomizedFieldReq,
    DeleteHelpdeskTicketCustomizedFieldResp,
    _gen_delete_helpdesk_ticket_customized_field_req,
)
from pylark.api_service_helpdesk_ticket_customized_field_update import (
    UpdateHelpdeskTicketCustomizedFieldReq,
    UpdateHelpdeskTicketCustomizedFieldResp,
    _gen_update_helpdesk_ticket_customized_field_req,
)
from pylark.api_service_helpdesk_ticket_customized_field_create import (
    CreateHelpdeskTicketCustomizedFieldReq,
    CreateHelpdeskTicketCustomizedFieldResp,
    _gen_create_helpdesk_ticket_customized_field_req,
)
from pylark.api_service_helpdesk_ticket_customized_field_get import (
    GetHelpdeskTicketCustomizedFieldReq,
    GetHelpdeskTicketCustomizedFieldResp,
    _gen_get_helpdesk_ticket_customized_field_req,
)
from pylark.api_service_helpdesk_category_create import (
    CreateHelpdeskCategoryReq,
    CreateHelpdeskCategoryResp,
    _gen_create_helpdesk_category_req,
)
from pylark.api_service_helpdesk_category_get import (
    GetHelpdeskCategoryReq,
    GetHelpdeskCategoryResp,
    _gen_get_helpdesk_category_req,
)
from pylark.api_service_helpdesk_category_update import (
    UpdateHelpdeskCategoryReq,
    UpdateHelpdeskCategoryResp,
    _gen_update_helpdesk_category_req,
)
from pylark.api_service_helpdesk_category_delete import (
    DeleteHelpdeskCategoryReq,
    DeleteHelpdeskCategoryResp,
    _gen_delete_helpdesk_category_req,
)
from pylark.api_service_helpdesk_category_get_list import (
    GetHelpdeskCategoryListReq,
    GetHelpdeskCategoryListResp,
    _gen_get_helpdesk_category_list_req,
)
from pylark.api_service_helpdesk_faq_create import (
    CreateHelpdeskFAQReq,
    CreateHelpdeskFAQResp,
    _gen_create_helpdesk_faq_req,
)
from pylark.api_service_helpdesk_faq_get import (
    GetHelpdeskFAQReq,
    GetHelpdeskFAQResp,
    _gen_get_helpdesk_faq_req,
)
from pylark.api_service_helpdesk_faq_update import (
    UpdateHelpdeskFAQReq,
    UpdateHelpdeskFAQResp,
    _gen_update_helpdesk_faq_req,
)
from pylark.api_service_helpdesk_faq_delete import (
    DeleteHelpdeskFAQReq,
    DeleteHelpdeskFAQResp,
    _gen_delete_helpdesk_faq_req,
)
from pylark.api_service_helpdesk_faq_get_list import (
    GetHelpdeskFAQListReq,
    GetHelpdeskFAQListResp,
    _gen_get_helpdesk_faq_list_req,
)
from pylark.api_service_helpdesk_faq_get_image import (
    GetHelpdeskFAQImageReq,
    GetHelpdeskFAQImageResp,
    _gen_get_helpdesk_faq_image_req,
)
from pylark.api_service_helpdesk_faq_search import (
    SearchHelpdeskFAQReq,
    SearchHelpdeskFAQResp,
    _gen_search_helpdesk_faq_req,
)
from pylark.api_service_helpdesk_agent_patch import (
    UpdateHelpdeskAgentReq,
    UpdateHelpdeskAgentResp,
    _gen_update_helpdesk_agent_req,
)
from pylark.api_service_helpdesk_agent_email_get import (
    GetHelpdeskAgentEmailReq,
    GetHelpdeskAgentEmailResp,
    _gen_get_helpdesk_agent_email_req,
)
from pylark.api_service_helpdesk_agent_schedule_create import (
    CreateHelpdeskAgentScheduleReq,
    CreateHelpdeskAgentScheduleResp,
    _gen_create_helpdesk_agent_schedule_req,
)
from pylark.api_service_helpdesk_agent_schedule_delete import (
    DeleteHelpdeskAgentScheduleReq,
    DeleteHelpdeskAgentScheduleResp,
    _gen_delete_helpdesk_agent_schedule_req,
)
from pylark.api_service_helpdesk_agent_schedule_update import (
    UpdateHelpdeskAgentScheduleReq,
    UpdateHelpdeskAgentScheduleResp,
    _gen_update_helpdesk_agent_schedule_req,
)
from pylark.api_service_helpdesk_agent_schedule_get import (
    GetHelpdeskAgentScheduleReq,
    GetHelpdeskAgentScheduleResp,
    _gen_get_helpdesk_agent_schedule_req,
)
from pylark.api_service_helpdesk_agent_schedule_get_list import (
    GetHelpdeskAgentScheduleListReq,
    GetHelpdeskAgentScheduleListResp,
    _gen_get_helpdesk_agent_schedule_list_req,
)
from pylark.api_service_helpdesk_agent_skill_create import (
    CreateHelpdeskAgentSkillReq,
    CreateHelpdeskAgentSkillResp,
    _gen_create_helpdesk_agent_skill_req,
)
from pylark.api_service_helpdesk_agent_skill_get import (
    GetHelpdeskAgentSkillReq,
    GetHelpdeskAgentSkillResp,
    _gen_get_helpdesk_agent_skill_req,
)
from pylark.api_service_helpdesk_agent_skill_update import (
    UpdateHelpdeskAgentSkillReq,
    UpdateHelpdeskAgentSkillResp,
    _gen_update_helpdesk_agent_skill_req,
)
from pylark.api_service_helpdesk_agent_skill_delete import (
    DeleteHelpdeskAgentSkillReq,
    DeleteHelpdeskAgentSkillResp,
    _gen_delete_helpdesk_agent_skill_req,
)
from pylark.api_service_helpdesk_agent_skill_get_list import (
    GetHelpdeskAgentSkillListReq,
    GetHelpdeskAgentSkillListResp,
    _gen_get_helpdesk_agent_skill_list_req,
)
from pylark.api_service_helpdesk_agent_skill_rule_get_list import (
    GetHelpdeskAgentSkillRuleListReq,
    GetHelpdeskAgentSkillRuleListResp,
    _gen_get_helpdesk_agent_skill_rule_list_req,
)
from pylark.api_service_helpdesk_event_subscribe import (
    SubscribeHelpdeskEventReq,
    SubscribeHelpdeskEventResp,
    _gen_subscribe_helpdesk_event_req,
)
from pylark.api_service_helpdesk_event_unsubscribe import (
    UnsubscribeHelpdeskEventReq,
    UnsubscribeHelpdeskEventResp,
    _gen_unsubscribe_helpdesk_event_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkHelpdeskService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def start_helpdesk_service(
        self, request: StartHelpdeskServiceReq, options: typing.List[str] = None
    ) -> typing.Tuple[StartHelpdeskServiceResp, Response]:
        return self.cli.raw_request(_gen_start_helpdesk_service_req(request, options))

    def get_helpdesk_ticket(
        self, request: GetHelpdeskTicketReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskTicketResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_ticket_req(request, options))

    def update_helpdesk_ticket(
        self, request: UpdateHelpdeskTicketReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskTicketResp, Response]:
        return self.cli.raw_request(_gen_update_helpdesk_ticket_req(request, options))

    def get_helpdesk_ticket_list(
        self, request: GetHelpdeskTicketListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskTicketListResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_ticket_list_req(request, options))

    def download_helpdesk_ticket_image(
        self, request: DownloadHelpdeskTicketImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadHelpdeskTicketImageResp, Response]:
        return self.cli.raw_request(
            _gen_download_helpdesk_ticket_image_req(request, options)
        )

    def answer_helpdesk_ticket_user_query(
        self,
        request: AnswerHelpdeskTicketUserQueryReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[AnswerHelpdeskTicketUserQueryResp, Response]:
        return self.cli.raw_request(
            _gen_answer_helpdesk_ticket_user_query_req(request, options)
        )

    def get_helpdesk_ticket_message_list(
        self, request: GetHelpdeskTicketMessageListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskTicketMessageListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_ticket_message_list_req(request, options)
        )

    def send_helpdesk_ticket_message(
        self, request: SendHelpdeskTicketMessageReq, options: typing.List[str] = None
    ) -> typing.Tuple[SendHelpdeskTicketMessageResp, Response]:
        return self.cli.raw_request(
            _gen_send_helpdesk_ticket_message_req(request, options)
        )

    def get_helpdesk_ticket_customized_field_list(
        self,
        request: GetHelpdeskTicketCustomizedFieldListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetHelpdeskTicketCustomizedFieldListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_ticket_customized_field_list_req(request, options)
        )

    def delete_helpdesk_ticket_customized_field(
        self,
        request: DeleteHelpdeskTicketCustomizedFieldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[DeleteHelpdeskTicketCustomizedFieldResp, Response]:
        return self.cli.raw_request(
            _gen_delete_helpdesk_ticket_customized_field_req(request, options)
        )

    def update_helpdesk_ticket_customized_field(
        self,
        request: UpdateHelpdeskTicketCustomizedFieldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateHelpdeskTicketCustomizedFieldResp, Response]:
        return self.cli.raw_request(
            _gen_update_helpdesk_ticket_customized_field_req(request, options)
        )

    def create_helpdesk_ticket_customized_field(
        self,
        request: CreateHelpdeskTicketCustomizedFieldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateHelpdeskTicketCustomizedFieldResp, Response]:
        return self.cli.raw_request(
            _gen_create_helpdesk_ticket_customized_field_req(request, options)
        )

    def get_helpdesk_ticket_customized_field(
        self,
        request: GetHelpdeskTicketCustomizedFieldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetHelpdeskTicketCustomizedFieldResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_ticket_customized_field_req(request, options)
        )

    def create_helpdesk_category(
        self, request: CreateHelpdeskCategoryReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHelpdeskCategoryResp, Response]:
        return self.cli.raw_request(_gen_create_helpdesk_category_req(request, options))

    def get_helpdesk_category(
        self, request: GetHelpdeskCategoryReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskCategoryResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_category_req(request, options))

    def update_helpdesk_category(
        self, request: UpdateHelpdeskCategoryReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskCategoryResp, Response]:
        return self.cli.raw_request(_gen_update_helpdesk_category_req(request, options))

    def delete_helpdesk_category(
        self, request: DeleteHelpdeskCategoryReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteHelpdeskCategoryResp, Response]:
        return self.cli.raw_request(_gen_delete_helpdesk_category_req(request, options))

    def get_helpdesk_category_list(
        self, request: GetHelpdeskCategoryListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskCategoryListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_category_list_req(request, options)
        )

    def create_helpdesk_faq(
        self, request: CreateHelpdeskFAQReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHelpdeskFAQResp, Response]:
        return self.cli.raw_request(_gen_create_helpdesk_faq_req(request, options))

    def get_helpdesk_faq(
        self, request: GetHelpdeskFAQReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskFAQResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_faq_req(request, options))

    def update_helpdesk_faq(
        self, request: UpdateHelpdeskFAQReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskFAQResp, Response]:
        return self.cli.raw_request(_gen_update_helpdesk_faq_req(request, options))

    def delete_helpdesk_faq(
        self, request: DeleteHelpdeskFAQReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteHelpdeskFAQResp, Response]:
        return self.cli.raw_request(_gen_delete_helpdesk_faq_req(request, options))

    def get_helpdesk_faq_list(
        self, request: GetHelpdeskFAQListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskFAQListResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_faq_list_req(request, options))

    def get_helpdesk_faq_image(
        self, request: GetHelpdeskFAQImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskFAQImageResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_faq_image_req(request, options))

    def search_helpdesk_faq(
        self, request: SearchHelpdeskFAQReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchHelpdeskFAQResp, Response]:
        return self.cli.raw_request(_gen_search_helpdesk_faq_req(request, options))

    def update_helpdesk_agent(
        self, request: UpdateHelpdeskAgentReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskAgentResp, Response]:
        return self.cli.raw_request(_gen_update_helpdesk_agent_req(request, options))

    def get_helpdesk_agent_email(
        self, request: GetHelpdeskAgentEmailReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskAgentEmailResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_agent_email_req(request, options))

    def create_helpdesk_agent_schedule(
        self, request: CreateHelpdeskAgentScheduleReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHelpdeskAgentScheduleResp, Response]:
        return self.cli.raw_request(
            _gen_create_helpdesk_agent_schedule_req(request, options)
        )

    def delete_helpdesk_agent_schedule(
        self, request: DeleteHelpdeskAgentScheduleReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteHelpdeskAgentScheduleResp, Response]:
        return self.cli.raw_request(
            _gen_delete_helpdesk_agent_schedule_req(request, options)
        )

    def update_helpdesk_agent_schedule(
        self, request: UpdateHelpdeskAgentScheduleReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskAgentScheduleResp, Response]:
        return self.cli.raw_request(
            _gen_update_helpdesk_agent_schedule_req(request, options)
        )

    def get_helpdesk_agent_schedule(
        self, request: GetHelpdeskAgentScheduleReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskAgentScheduleResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_agent_schedule_req(request, options)
        )

    def get_helpdesk_agent_schedule_list(
        self, request: GetHelpdeskAgentScheduleListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskAgentScheduleListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_agent_schedule_list_req(request, options)
        )

    def create_helpdesk_agent_skill(
        self, request: CreateHelpdeskAgentSkillReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateHelpdeskAgentSkillResp, Response]:
        return self.cli.raw_request(
            _gen_create_helpdesk_agent_skill_req(request, options)
        )

    def get_helpdesk_agent_skill(
        self, request: GetHelpdeskAgentSkillReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskAgentSkillResp, Response]:
        return self.cli.raw_request(_gen_get_helpdesk_agent_skill_req(request, options))

    def update_helpdesk_agent_skill(
        self, request: UpdateHelpdeskAgentSkillReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateHelpdeskAgentSkillResp, Response]:
        return self.cli.raw_request(
            _gen_update_helpdesk_agent_skill_req(request, options)
        )

    def delete_helpdesk_agent_skill(
        self, request: DeleteHelpdeskAgentSkillReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteHelpdeskAgentSkillResp, Response]:
        return self.cli.raw_request(
            _gen_delete_helpdesk_agent_skill_req(request, options)
        )

    def get_helpdesk_agent_skill_list(
        self, request: GetHelpdeskAgentSkillListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetHelpdeskAgentSkillListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_agent_skill_list_req(request, options)
        )

    def get_helpdesk_agent_skill_rule_list(
        self,
        request: GetHelpdeskAgentSkillRuleListReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetHelpdeskAgentSkillRuleListResp, Response]:
        return self.cli.raw_request(
            _gen_get_helpdesk_agent_skill_rule_list_req(request, options)
        )

    def subscribe_helpdesk_event(
        self, request: SubscribeHelpdeskEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[SubscribeHelpdeskEventResp, Response]:
        return self.cli.raw_request(_gen_subscribe_helpdesk_event_req(request, options))

    def unsubscribe_helpdesk_event(
        self, request: UnsubscribeHelpdeskEventReq, options: typing.List[str] = None
    ) -> typing.Tuple[UnsubscribeHelpdeskEventResp, Response]:
        return self.cli.raw_request(
            _gen_unsubscribe_helpdesk_event_req(request, options)
        )



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['pylark']

package_data = \
{'': ['*']}

install_requires = \
['attrs>=21.2.0,<22.0.0', 'pytest>=6.2.4,<7.0.0', 'requests>=2.26.0,<3.0.0']

setup_kwargs = {
    'name': 'pylark',
    'version': '0.0.6',
    'description': 'Feishu/Lark Open API Python Sdk, Support ALL Open API and Event Callback.',
    'long_description': None,
    'author': 'chyroc',
    'author_email': 'chyroc@qq.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class AddSheetDimensionRangeReqDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认 ROWS ，可选 ROWS、COLUMNS
    length: int = attr.ib(
        default=0, metadata={"req_type": "json"}
    )  # 要增加的行/列数,0<length<5000


@attr.s
class AddSheetDimensionRangeReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，详见 [在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    dimension: AddSheetDimensionRangeReqDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要增加行列的维度信息


@attr.s
class AddSheetDimensionRangeResp(object):
    add_count: int = attr.ib(default=0, metadata={"req_type": "json"})  # 增加的行/列数
    major_dimension: str = attr.ib(default="", metadata={"req_type": "json"})  # 插入维度


def _gen_add_sheet_dimension_range_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=AddSheetDimensionRangeResp,
        scope="Drive",
        api="AddSheetDimensionRange",
        method="POST",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dimension_range",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteSheetProtectedDimensionReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # sheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    protect_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 需要删除的保护范围ID，可以通过[获取表格元数据](https://open.feishu.cn/document/ukTMukTMukTM/uETMzUjLxEzM14SMxMTN)接口获取


@attr.s
class DeleteSheetProtectedDimensionResp(object):
    del_protect_ids: typing.List[str] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 成功删除的保护范围ID


def _gen_delete_sheet_protected_dimension_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteSheetProtectedDimensionResp,
        scope="Drive",
        api="DeleteSheetProtectedDimension",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/protected_range_batch_del",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetBitableTableListReq(object):
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 分页标记，第一次请求不填，表示从头开始遍历；分页查询结果还有更多项时会同时返回新的 page_token，下次遍历可采用该 page_token 获取查询结果, 示例值："tblsRc9GRRXKqhvW"
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 分页大小, 示例值：10, 最大值：`100`
    app_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # bitable app token, 示例值："appbcbWCzen6D8dezhoCH2RpMAh"


@attr.s
class GetBitableTableListRespItem(object):
    table_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 表格表 id
    revision: int = attr.ib(default=0, metadata={"req_type": "json"})  # 数据表的版本号
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 数据表 名字


@attr.s
class GetBitableTableListResp(object):
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有更多项
    page_token: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 分页标记，当 has_more 为 true 时，会同时返回新的 page_token，否则不返回 page_token
    items: typing.List[GetBitableTableListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # 数据表信息


def _gen_get_bitable_table_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetBitableTableListResp,
        scope="Bitable",
        api="GetBitableTableList",
        method="GET",
        url="https://open.feishu.cn/open-apis/bitable/v1/apps/:app_token/tables",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class UpdateSheetDimensionRangeReqDimensionProperties(object):
    visible: bool = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # true 为显示，false 为隐藏行列
    fixed_size: int = attr.ib(default=0, metadata={"req_type": "json"})  # 行/列的大小


@attr.s
class UpdateSheetDimensionRangeReqDimension(object):
    sheet_id: str = attr.ib(default="", metadata={"req_type": "json"})  # sheetId
    major_dimension: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 默认 ROWS ，可选 ROWS、COLUMNS
    start_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 开始的位置
    end_index: int = attr.ib(default=0, metadata={"req_type": "json"})  # 结束的位置


@attr.s
class UpdateSheetDimensionRangeReq(object):
    spreadsheet_token: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # spreadsheet 的 token，获取方式见[在线表格开发指南](https://open.feishu.cn/document/ukTMukTMukTM/uATMzUjLwEzM14CMxMTN/overview)
    dimension: UpdateSheetDimensionRangeReqDimension = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要更新行列的维度信息
    dimension_properties: UpdateSheetDimensionRangeReqDimensionProperties = attr.ib(
        default=None, metadata={"req_type": "json"}
    )  # 需要更新行列的属性


@attr.s
class UpdateSheetDimensionRangeResp(object):
    pass


def _gen_update_sheet_dimension_range_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=UpdateSheetDimensionRangeResp,
        scope="Drive",
        api="UpdateSheetDimensionRange",
        method="PUT",
        url="https://open.feishu.cn/open-apis/sheets/v2/spreadsheets/:spreadsheetToken/dimension_range",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DeleteVCReserveReq(object):
    reserve_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 预约ID（预约的唯一标识）, 示例值："6911188411932033028"


@attr.s
class DeleteVCReserveResp(object):
    pass


def _gen_delete_vc_reserve_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DeleteVCReserveResp,
        scope="VC",
        api="DeleteVCReserve",
        method="DELETE",
        url="https://open.feishu.cn/open-apis/vc/v1/reserves/:reserve_id",
        body=request,
        method_option=_new_method_option(options),
        need_user_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class DownloadHelpdeskTicketImageReq(object):
    ticket_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 工单ID, 示例值："12345"
    msg_id: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 消息ID, 示例值："12345"
    index: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # index，当消息类型为post时，需指定图片index，index从0开始。当消息类型为img时，无需index, 示例值：0


@attr.s
class DownloadHelpdeskTicketImageRespFile(object):
    pass


@attr.s
class DownloadHelpdeskTicketImageResp(object):
    file: typing.Union[str, bytes, io.BytesIO] = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


@attr.s
class DownloadHelpdeskTicketImageResp(object):
    is_file: bool = attr.ib(factory=lambda: bool(), metadata={"req_type": "json"})
    code: int = attr.ib(default=0, metadata={"req_type": "json"})
    msg: str = attr.ib(default="", metadata={"req_type": "json"})
    data: DownloadHelpdeskTicketImageResp = attr.ib(
        default=None, metadata={"req_type": "json"}
    )


def _gen_download_helpdesk_ticket_image_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=DownloadHelpdeskTicketImageResp,
        scope="Helpdesk",
        api="DownloadHelpdeskTicketImage",
        method="GET",
        url="https://open.feishu.cn/open-apis/helpdesk/v1/ticket_images",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
        need_helpdesk_auth=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

import typing
from pylark.lark_request import Response

from pylark.api_service_drive_file_search import (
    SearchDriveFileReq,
    SearchDriveFileResp,
    _gen_search_drive_file_req,
)
from pylark.api_service_drive_file_meta_get import (
    GetDriveFileMetaReq,
    GetDriveFileMetaResp,
    _gen_get_drive_file_meta_req,
)
from pylark.api_service_drive_file_create import (
    CreateDriveFileReq,
    CreateDriveFileResp,
    _gen_create_drive_file_req,
)
from pylark.api_service_drive_file_copy import (
    CopyDriveFileReq,
    CopyDriveFileResp,
    _gen_copy_drive_file_req,
)
from pylark.api_service_drive_file_delete import (
    DeleteDriveFileReq,
    DeleteDriveFileResp,
    _gen_delete_drive_file_req,
)
from pylark.api_service_drive_file_sheet_delete import (
    DeleteDriveSheetFileReq,
    DeleteDriveSheetFileResp,
    _gen_delete_drive_sheet_file_req,
)
from pylark.api_service_drive_folder_create import (
    CreateDriveFolderReq,
    CreateDriveFolderResp,
    _gen_create_drive_folder_req,
)
from pylark.api_service_drive_folder_meta import (
    GetDriveFolderMetaReq,
    GetDriveFolderMetaResp,
    _gen_get_drive_folder_meta_req,
)
from pylark.api_service_drive_folder_root_meta import (
    GetDriveRootFolderMetaReq,
    GetDriveRootFolderMetaResp,
    _gen_get_drive_root_folder_meta_req,
)
from pylark.api_service_drive_folder_children_get import (
    GetDriveFolderChildrenReq,
    GetDriveFolderChildrenResp,
    _gen_get_drive_folder_children_req,
)
from pylark.api_service_drive_file_statistics_get import (
    GetDriveFileStatisticsReq,
    GetDriveFileStatisticsResp,
    _gen_get_drive_file_statistics_req,
)
from pylark.api_service_drive_file_download import (
    DownloadDriveFileReq,
    DownloadDriveFileResp,
    _gen_download_drive_file_req,
)
from pylark.api_service_drive_file_upload_all import (
    UploadDriveFileReq,
    UploadDriveFileResp,
    _gen_upload_drive_file_req,
)
from pylark.api_service_drive_file_upload_prepare import (
    PrepareUploadDriveFileReq,
    PrepareUploadDriveFileResp,
    _gen_prepare_upload_drive_file_req,
)
from pylark.api_service_drive_file_upload_part import (
    PartUploadDriveFileReq,
    PartUploadDriveFileResp,
    _gen_part_upload_drive_file_req,
)
from pylark.api_service_drive_file_upload_finish import (
    FinishUploadDriveFileReq,
    FinishUploadDriveFileResp,
    _gen_finish_upload_drive_file_req,
)
from pylark.api_service_drive_media_download import (
    DownloadDriveMediaReq,
    DownloadDriveMediaResp,
    _gen_download_drive_media_req,
)
from pylark.api_service_drive_media_upload_all import (
    UploadDriveMediaReq,
    UploadDriveMediaResp,
    _gen_upload_drive_media_req,
)
from pylark.api_service_drive_media_upload_prepare import (
    PrepareUploadDriveMediaReq,
    PrepareUploadDriveMediaResp,
    _gen_prepare_upload_drive_media_req,
)
from pylark.api_service_drive_media_upload_part import (
    PartUploadDriveMediaReq,
    PartUploadDriveMediaResp,
    _gen_part_upload_drive_media_req,
)
from pylark.api_service_drive_media_upload_finish import (
    FinishUploadDriveMediaReq,
    FinishUploadDriveMediaResp,
    _gen_finish_upload_drive_media_req,
)
from pylark.api_service_drive_permission_member_create_old import (
    CreateDriveMemberPermissionOldReq,
    CreateDriveMemberPermissionOldResp,
    _gen_create_drive_member_permission_old_req,
)
from pylark.api_service_drive_permission_member_transfer import (
    TransferDriveMemberPermissionReq,
    TransferDriveMemberPermissionResp,
    _gen_transfer_drive_member_permission_req,
)
from pylark.api_service_drive_permission_member_list import (
    GetDriveMemberPermissionListReq,
    GetDriveMemberPermissionListResp,
    _gen_get_drive_member_permission_list_req,
)
from pylark.api_service_drive_permission_member_create import (
    CreateDriveMemberPermissionReq,
    CreateDriveMemberPermissionResp,
    _gen_create_drive_member_permission_req,
)
from pylark.api_service_drive_permission_member_delete import (
    DeleteDriveMemberPermissionReq,
    DeleteDriveMemberPermissionResp,
    _gen_delete_drive_member_permission_req,
)
from pylark.api_service_drive_permission_member_update import (
    UpdateDriveMemberPermissionReq,
    UpdateDriveMemberPermissionResp,
    _gen_update_drive_member_permission_req,
)
from pylark.api_service_drive_permission_member_check import (
    CheckDriveMemberPermissionReq,
    CheckDriveMemberPermissionResp,
    _gen_check_drive_member_permission_req,
)
from pylark.api_service_drive_permission_public_update_v1_old import (
    UpdateDrivePublicPermissionV1OldReq,
    UpdateDrivePublicPermissionV1OldResp,
    _gen_update_drive_public_permission_v1_old_req,
)
from pylark.api_service_drive_permission_public_update_v2_old import (
    UpdateDrivePublicPermissionV2OldReq,
    UpdateDrivePublicPermissionV2OldResp,
    _gen_update_drive_public_permission_v2_old_req,
)
from pylark.api_service_drive_permission_public_get_v2 import (
    GetDrivePublicPermissionV2Req,
    GetDrivePublicPermissionV2Resp,
    _gen_get_drive_public_permission_v2_req,
)
from pylark.api_service_drive_permission_public_patch import (
    UpdateDrivePublicPermissionReq,
    UpdateDrivePublicPermissionResp,
    _gen_update_drive_public_permission_req,
)
from pylark.api_service_drive_media_batch_get_tmp_download_url import (
    BatchGetDriveMediaTmpDownloadURLReq,
    BatchGetDriveMediaTmpDownloadURLResp,
    _gen_batch_get_drive_media_tmp_download_url_req,
)
from pylark.api_service_drive_comment_list import (
    GetDriveCommentListReq,
    GetDriveCommentListResp,
    _gen_get_drive_comment_list_req,
)
from pylark.api_service_drive_comment_get import (
    GetDriveCommentReq,
    GetDriveCommentResp,
    _gen_get_drive_comment_req,
)
from pylark.api_service_drive_comment_create import (
    CreateDriveCommentReq,
    CreateDriveCommentResp,
    _gen_create_drive_comment_req,
)
from pylark.api_service_drive_comment_update import (
    UpdateDriveCommentReq,
    UpdateDriveCommentResp,
    _gen_update_drive_comment_req,
)
from pylark.api_service_drive_comment_delete import (
    DeleteDriveCommentReq,
    DeleteDriveCommentResp,
    _gen_delete_drive_comment_req,
)
from pylark.api_service_drive_comment_patch import (
    UpdateDriveCommentPatchReq,
    UpdateDriveCommentPatchResp,
    _gen_update_drive_comment_patch_req,
)
from pylark.api_service_drive_doc_create import (
    CreateDriveDocReq,
    CreateDriveDocResp,
    _gen_create_drive_doc_req,
)
from pylark.api_service_drive_doc_content_get import (
    GetDriveDocContentReq,
    GetDriveDocContentResp,
    _gen_get_drive_doc_content_req,
)
from pylark.api_service_drive_doc_raw_content_get import (
    GetDriveDocRawContentReq,
    GetDriveDocRawContentResp,
    _gen_get_drive_doc_raw_content_req,
)
from pylark.api_service_drive_doc_meta_get import (
    GetDriveDocMetaReq,
    GetDriveDocMetaResp,
    _gen_get_drive_doc_meta_req,
)
from pylark.api_service_drive_sheet_create import (
    CreateSheetReq,
    CreateSheetResp,
    _gen_create_sheet_req,
)
from pylark.api_service_drive_sheet_meta_get import (
    GetSheetMetaReq,
    GetSheetMetaResp,
    _gen_get_sheet_meta_req,
)
from pylark.api_service_drive_sheet_property_update import (
    UpdateSheetPropertyReq,
    UpdateSheetPropertyResp,
    _gen_update_sheet_property_req,
)
from pylark.api_service_drive_sheet_batch_update import (
    BatchUpdateSheetReq,
    BatchUpdateSheetResp,
    _gen_batch_update_sheet_req,
)
from pylark.api_service_drive_sheet_import import (
    ImportSheetReq,
    ImportSheetResp,
    _gen_import_sheet_req,
)
from pylark.api_service_drive_import_task_create import (
    CreateDriveImportTaskReq,
    CreateDriveImportTaskResp,
    _gen_create_drive_import_task_req,
)
from pylark.api_service_drive_import_task_get import (
    GetDriveImportTaskReq,
    GetDriveImportTaskResp,
    _gen_get_drive_import_task_req,
)
from pylark.api_service_drive_sheet_dimension_move import (
    MoveSheetDimensionReq,
    MoveSheetDimensionResp,
    _gen_move_sheet_dimension_req,
)
from pylark.api_service_drive_sheet_value_prepend import (
    PrependSheetValueReq,
    PrependSheetValueResp,
    _gen_prepend_sheet_value_req,
)
from pylark.api_service_drive_sheet_value_append import (
    AppendSheetValueReq,
    AppendSheetValueResp,
    _gen_append_sheet_value_req,
)
from pylark.api_service_drive_sheet_dimension_range_insert import (
    InsertSheetDimensionRangeReq,
    InsertSheetDimensionRangeResp,
    _gen_insert_sheet_dimension_range_req,
)
from pylark.api_service_drive_sheet_dimension_range_add import (
    AddSheetDimensionRangeReq,
    AddSheetDimensionRangeResp,
    _gen_add_sheet_dimension_range_req,
)
from pylark.api_service_drive_sheet_dimension_range_update import (
    UpdateSheetDimensionRangeReq,
    UpdateSheetDimensionRangeResp,
    _gen_update_sheet_dimension_range_req,
)
from pylark.api_service_drive_sheet_dimension_range_delete import (
    DeleteSheetDimensionRangeReq,
    DeleteSheetDimensionRangeResp,
    _gen_delete_sheet_dimension_range_req,
)
from pylark.api_service_drive_sheet_value_get import (
    GetSheetValueReq,
    GetSheetValueResp,
    _gen_get_sheet_value_req,
)
from pylark.api_service_drive_sheet_value_batch_get import (
    BatchGetSheetValueReq,
    BatchGetSheetValueResp,
    _gen_batch_get_sheet_value_req,
)
from pylark.api_service_drive_sheet_value_set import (
    SetSheetValueReq,
    SetSheetValueResp,
    _gen_set_sheet_value_req,
)
from pylark.api_service_drive_sheet_value_batch_set import (
    BatchSetSheetValueReq,
    BatchSetSheetValueResp,
    _gen_batch_set_sheet_value_req,
)
from pylark.api_service_drive_sheet_style_set import (
    SetSheetStyleReq,
    SetSheetStyleResp,
    _gen_set_sheet_style_req,
)
from pylark.api_service_drive_sheet_style_batch_set import (
    BatchSetSheetStyleReq,
    BatchSetSheetStyleResp,
    _gen_batch_set_sheet_style_req,
)
from pylark.api_service_drive_sheet_cell_merge import (
    MergeSheetCellReq,
    MergeSheetCellResp,
    _gen_merge_sheet_cell_req,
)
from pylark.api_service_drive_sheet_cell_unmerge import (
    UnmergeSheetCellReq,
    UnmergeSheetCellResp,
    _gen_unmerge_sheet_cell_req,
)
from pylark.api_service_drive_sheet_image_set import (
    SetSheetValueImageReq,
    SetSheetValueImageResp,
    _gen_set_sheet_value_image_req,
)
from pylark.api_service_drive_sheet_find import (
    FindSheetReq,
    FindSheetResp,
    _gen_find_sheet_req,
)
from pylark.api_service_drive_sheet_replace import (
    ReplaceSheetReq,
    ReplaceSheetResp,
    _gen_replace_sheet_req,
)
from pylark.api_service_drive_sheet_condition_format_create import (
    CreateSheetConditionFormatReq,
    CreateSheetConditionFormatResp,
    _gen_create_sheet_condition_format_req,
)
from pylark.api_service_drive_sheet_condition_format_get import (
    GetSheetConditionFormatReq,
    GetSheetConditionFormatResp,
    _gen_get_sheet_condition_format_req,
)
from pylark.api_service_drive_sheet_condition_format_update import (
    UpdateSheetConditionFormatReq,
    UpdateSheetConditionFormatResp,
    _gen_update_sheet_condition_format_req,
)
from pylark.api_service_drive_sheet_condition_format_delete import (
    DeleteSheetConditionFormatReq,
    DeleteSheetConditionFormatResp,
    _gen_delete_sheet_condition_format_req,
)
from pylark.api_service_drive_sheet_protected_dimension_create import (
    CreateSheetProtectedDimensionReq,
    CreateSheetProtectedDimensionResp,
    _gen_create_sheet_protected_dimension_req,
)
from pylark.api_service_drive_sheet_protected_dimension_get import (
    GetSheetProtectedDimensionReq,
    GetSheetProtectedDimensionResp,
    _gen_get_sheet_protected_dimension_req,
)
from pylark.api_service_drive_sheet_protected_dimension_update import (
    UpdateSheetProtectedDimensionReq,
    UpdateSheetProtectedDimensionResp,
    _gen_update_sheet_protected_dimension_req,
)
from pylark.api_service_drive_sheet_protected_dimension_delete import (
    DeleteSheetProtectedDimensionReq,
    DeleteSheetProtectedDimensionResp,
    _gen_delete_sheet_protected_dimension_req,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_create import (
    CreateSheetDataValidationDropdownReq,
    CreateSheetDataValidationDropdownResp,
    _gen_create_sheet_data_validation_dropdown_req,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_delete import (
    DeleteSheetDataValidationDropdownReq,
    DeleteSheetDataValidationDropdownResp,
    _gen_delete_sheet_data_validation_dropdown_req,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_update import (
    UpdateSheetDataValidationDropdownReq,
    UpdateSheetDataValidationDropdownResp,
    _gen_update_sheet_data_validation_dropdown_req,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_get import (
    GetSheetDataValidationDropdownReq,
    GetSheetDataValidationDropdownResp,
    _gen_get_sheet_data_validation_dropdown_req,
)
from pylark.api_service_drive_sheet_filter_create import (
    CreateSheetFilterReq,
    CreateSheetFilterResp,
    _gen_create_sheet_filter_req,
)
from pylark.api_service_drive_sheet_filter_delete import (
    DeleteSheetFilterReq,
    DeleteSheetFilterResp,
    _gen_delete_sheet_filter_req,
)
from pylark.api_service_drive_sheet_filter_update import (
    UpdateSheetFilterReq,
    UpdateSheetFilterResp,
    _gen_update_sheet_filter_req,
)
from pylark.api_service_drive_sheet_filter_get import (
    GetSheetFilterReq,
    GetSheetFilterResp,
    _gen_get_sheet_filter_req,
)
from pylark.api_service_drive_sheet_filter_view_create import (
    CreateSheetFilterViewReq,
    CreateSheetFilterViewResp,
    _gen_create_sheet_filter_view_req,
)
from pylark.api_service_drive_sheet_filter_view_delete import (
    DeleteSheetFilterViewReq,
    DeleteSheetFilterViewResp,
    _gen_delete_sheet_filter_view_req,
)
from pylark.api_service_drive_sheet_filter_view_update import (
    UpdateSheetFilterViewReq,
    UpdateSheetFilterViewResp,
    _gen_update_sheet_filter_view_req,
)
from pylark.api_service_drive_sheet_filter_view_get import (
    GetSheetFilterViewReq,
    GetSheetFilterViewResp,
    _gen_get_sheet_filter_view_req,
)
from pylark.api_service_drive_sheet_filter_view_query import (
    QuerySheetFilterViewReq,
    QuerySheetFilterViewResp,
    _gen_query_sheet_filter_view_req,
)
from pylark.api_service_drive_sheet_filter_view_condition_create import (
    CreateSheetFilterViewConditionReq,
    CreateSheetFilterViewConditionResp,
    _gen_create_sheet_filter_view_condition_req,
)
from pylark.api_service_drive_sheet_filter_view_condition_delete import (
    DeleteSheetFilterViewConditionReq,
    DeleteSheetFilterViewConditionResp,
    _gen_delete_sheet_filter_view_condition_req,
)
from pylark.api_service_drive_sheet_filter_view_condition_update import (
    UpdateSheetFilterViewConditionReq,
    UpdateSheetFilterViewConditionResp,
    _gen_update_sheet_filter_view_condition_req,
)
from pylark.api_service_drive_sheet_filter_view_condition_get import (
    GetSheetFilterViewConditionReq,
    GetSheetFilterViewConditionResp,
    _gen_get_sheet_filter_view_condition_req,
)
from pylark.api_service_drive_sheet_filter_view_condition_query import (
    QuerySheetFilterViewConditionReq,
    QuerySheetFilterViewConditionResp,
    _gen_query_sheet_filter_view_condition_req,
)
from pylark.api_service_drive_sheet_float_image_create import (
    CreateSheetFloatImageReq,
    CreateSheetFloatImageResp,
    _gen_create_sheet_float_image_req,
)
from pylark.api_service_drive_sheet_float_image_delete import (
    DeleteSheetFloatImageReq,
    DeleteSheetFloatImageResp,
    _gen_delete_sheet_float_image_req,
)
from pylark.api_service_drive_sheet_float_image_update import (
    UpdateSheetFloatImageReq,
    UpdateSheetFloatImageResp,
    _gen_update_sheet_float_image_req,
)
from pylark.api_service_drive_sheet_float_image_get import (
    GetSheetFloatImageReq,
    GetSheetFloatImageResp,
    _gen_get_sheet_float_image_req,
)
from pylark.api_service_drive_sheet_float_image_query import (
    QuerySheetFloatImageReq,
    QuerySheetFloatImageResp,
    _gen_query_sheet_float_image_req,
)


if typing.TYPE_CHECKING:
    from lark import Lark


class LarkDriveService(object):
    cli: "Lark"

    def __init__(self, cli: "Lark"):
        self.cli = cli

    def search_drive_file(
        self, request: SearchDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[SearchDriveFileResp, Response]:
        return self.cli.raw_request(_gen_search_drive_file_req(request, options))

    def get_drive_file_meta(
        self, request: GetDriveFileMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveFileMetaResp, Response]:
        return self.cli.raw_request(_gen_get_drive_file_meta_req(request, options))

    def create_drive_file(
        self, request: CreateDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveFileResp, Response]:
        return self.cli.raw_request(_gen_create_drive_file_req(request, options))

    def copy_drive_file(
        self, request: CopyDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[CopyDriveFileResp, Response]:
        return self.cli.raw_request(_gen_copy_drive_file_req(request, options))

    def delete_drive_file(
        self, request: DeleteDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteDriveFileResp, Response]:
        return self.cli.raw_request(_gen_delete_drive_file_req(request, options))

    def delete_drive_sheet_file(
        self, request: DeleteDriveSheetFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteDriveSheetFileResp, Response]:
        return self.cli.raw_request(_gen_delete_drive_sheet_file_req(request, options))

    def create_drive_folder(
        self, request: CreateDriveFolderReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveFolderResp, Response]:
        return self.cli.raw_request(_gen_create_drive_folder_req(request, options))

    def get_drive_folder_meta(
        self, request: GetDriveFolderMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveFolderMetaResp, Response]:
        return self.cli.raw_request(_gen_get_drive_folder_meta_req(request, options))

    def get_drive_root_folder_meta(
        self, request: GetDriveRootFolderMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveRootFolderMetaResp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_root_folder_meta_req(request, options)
        )

    def get_drive_folder_children(
        self, request: GetDriveFolderChildrenReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveFolderChildrenResp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_folder_children_req(request, options)
        )

    def get_drive_file_statistics(
        self, request: GetDriveFileStatisticsReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveFileStatisticsResp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_file_statistics_req(request, options)
        )

    def download_drive_file(
        self, request: DownloadDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadDriveFileResp, Response]:
        return self.cli.raw_request(_gen_download_drive_file_req(request, options))

    def upload_drive_file(
        self, request: UploadDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadDriveFileResp, Response]:
        return self.cli.raw_request(_gen_upload_drive_file_req(request, options))

    def prepare_upload_drive_file(
        self, request: PrepareUploadDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[PrepareUploadDriveFileResp, Response]:
        return self.cli.raw_request(
            _gen_prepare_upload_drive_file_req(request, options)
        )

    def part_upload_drive_file(
        self, request: PartUploadDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[PartUploadDriveFileResp, Response]:
        return self.cli.raw_request(_gen_part_upload_drive_file_req(request, options))

    def finish_upload_drive_file(
        self, request: FinishUploadDriveFileReq, options: typing.List[str] = None
    ) -> typing.Tuple[FinishUploadDriveFileResp, Response]:
        return self.cli.raw_request(_gen_finish_upload_drive_file_req(request, options))

    def download_drive_media(
        self, request: DownloadDriveMediaReq, options: typing.List[str] = None
    ) -> typing.Tuple[DownloadDriveMediaResp, Response]:
        return self.cli.raw_request(_gen_download_drive_media_req(request, options))

    def upload_drive_media(
        self, request: UploadDriveMediaReq, options: typing.List[str] = None
    ) -> typing.Tuple[UploadDriveMediaResp, Response]:
        return self.cli.raw_request(_gen_upload_drive_media_req(request, options))

    def prepare_upload_drive_media(
        self, request: PrepareUploadDriveMediaReq, options: typing.List[str] = None
    ) -> typing.Tuple[PrepareUploadDriveMediaResp, Response]:
        return self.cli.raw_request(
            _gen_prepare_upload_drive_media_req(request, options)
        )

    def part_upload_drive_media(
        self, request: PartUploadDriveMediaReq, options: typing.List[str] = None
    ) -> typing.Tuple[PartUploadDriveMediaResp, Response]:
        return self.cli.raw_request(_gen_part_upload_drive_media_req(request, options))

    def finish_upload_drive_media(
        self, request: FinishUploadDriveMediaReq, options: typing.List[str] = None
    ) -> typing.Tuple[FinishUploadDriveMediaResp, Response]:
        return self.cli.raw_request(
            _gen_finish_upload_drive_media_req(request, options)
        )

    def create_drive_member_permission_old(
        self,
        request: CreateDriveMemberPermissionOldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateDriveMemberPermissionOldResp, Response]:
        return self.cli.raw_request(
            _gen_create_drive_member_permission_old_req(request, options)
        )

    def transfer_drive_member_permission(
        self,
        request: TransferDriveMemberPermissionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[TransferDriveMemberPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_transfer_drive_member_permission_req(request, options)
        )

    def get_drive_member_permission_list(
        self, request: GetDriveMemberPermissionListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveMemberPermissionListResp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_member_permission_list_req(request, options)
        )

    def create_drive_member_permission(
        self, request: CreateDriveMemberPermissionReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveMemberPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_create_drive_member_permission_req(request, options)
        )

    def delete_drive_member_permission(
        self, request: DeleteDriveMemberPermissionReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteDriveMemberPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_delete_drive_member_permission_req(request, options)
        )

    def update_drive_member_permission(
        self, request: UpdateDriveMemberPermissionReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDriveMemberPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_update_drive_member_permission_req(request, options)
        )

    def check_drive_member_permission(
        self, request: CheckDriveMemberPermissionReq, options: typing.List[str] = None
    ) -> typing.Tuple[CheckDriveMemberPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_check_drive_member_permission_req(request, options)
        )

    def update_drive_public_permission_v1_old(
        self,
        request: UpdateDrivePublicPermissionV1OldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateDrivePublicPermissionV1OldResp, Response]:
        return self.cli.raw_request(
            _gen_update_drive_public_permission_v1_old_req(request, options)
        )

    def update_drive_public_permission_v2_old(
        self,
        request: UpdateDrivePublicPermissionV2OldReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateDrivePublicPermissionV2OldResp, Response]:
        return self.cli.raw_request(
            _gen_update_drive_public_permission_v2_old_req(request, options)
        )

    def get_drive_public_permission_v2(
        self, request: GetDrivePublicPermissionV2Req, options: typing.List[str] = None
    ) -> typing.Tuple[GetDrivePublicPermissionV2Resp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_public_permission_v2_req(request, options)
        )

    def update_drive_public_permission(
        self, request: UpdateDrivePublicPermissionReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDrivePublicPermissionResp, Response]:
        return self.cli.raw_request(
            _gen_update_drive_public_permission_req(request, options)
        )

    def batch_get_drive_media_tmp_download_url(
        self,
        request: BatchGetDriveMediaTmpDownloadURLReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[BatchGetDriveMediaTmpDownloadURLResp, Response]:
        return self.cli.raw_request(
            _gen_batch_get_drive_media_tmp_download_url_req(request, options)
        )

    def get_drive_comment_list(
        self, request: GetDriveCommentListReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveCommentListResp, Response]:
        return self.cli.raw_request(_gen_get_drive_comment_list_req(request, options))

    def get_drive_comment(
        self, request: GetDriveCommentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveCommentResp, Response]:
        return self.cli.raw_request(_gen_get_drive_comment_req(request, options))

    def create_drive_comment(
        self, request: CreateDriveCommentReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveCommentResp, Response]:
        return self.cli.raw_request(_gen_create_drive_comment_req(request, options))

    def update_drive_comment(
        self, request: UpdateDriveCommentReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDriveCommentResp, Response]:
        return self.cli.raw_request(_gen_update_drive_comment_req(request, options))

    def delete_drive_comment(
        self, request: DeleteDriveCommentReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteDriveCommentResp, Response]:
        return self.cli.raw_request(_gen_delete_drive_comment_req(request, options))

    def update_drive_comment_patch(
        self, request: UpdateDriveCommentPatchReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateDriveCommentPatchResp, Response]:
        return self.cli.raw_request(
            _gen_update_drive_comment_patch_req(request, options)
        )

    def create_drive_doc(
        self, request: CreateDriveDocReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveDocResp, Response]:
        return self.cli.raw_request(_gen_create_drive_doc_req(request, options))

    def get_drive_doc_content(
        self, request: GetDriveDocContentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveDocContentResp, Response]:
        return self.cli.raw_request(_gen_get_drive_doc_content_req(request, options))

    def get_drive_doc_raw_content(
        self, request: GetDriveDocRawContentReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveDocRawContentResp, Response]:
        return self.cli.raw_request(
            _gen_get_drive_doc_raw_content_req(request, options)
        )

    def get_drive_doc_meta(
        self, request: GetDriveDocMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveDocMetaResp, Response]:
        return self.cli.raw_request(_gen_get_drive_doc_meta_req(request, options))

    def create_sheet(
        self, request: CreateSheetReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSheetResp, Response]:
        return self.cli.raw_request(_gen_create_sheet_req(request, options))

    def get_sheet_meta(
        self, request: GetSheetMetaReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetMetaResp, Response]:
        return self.cli.raw_request(_gen_get_sheet_meta_req(request, options))

    def update_sheet_property(
        self, request: UpdateSheetPropertyReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetPropertyResp, Response]:
        return self.cli.raw_request(_gen_update_sheet_property_req(request, options))

    def batch_update_sheet(
        self, request: BatchUpdateSheetReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchUpdateSheetResp, Response]:
        return self.cli.raw_request(_gen_batch_update_sheet_req(request, options))

    def import_sheet(
        self, request: ImportSheetReq, options: typing.List[str] = None
    ) -> typing.Tuple[ImportSheetResp, Response]:
        return self.cli.raw_request(_gen_import_sheet_req(request, options))

    def create_drive_import_task(
        self, request: CreateDriveImportTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateDriveImportTaskResp, Response]:
        return self.cli.raw_request(_gen_create_drive_import_task_req(request, options))

    def get_drive_import_task(
        self, request: GetDriveImportTaskReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetDriveImportTaskResp, Response]:
        return self.cli.raw_request(_gen_get_drive_import_task_req(request, options))

    def move_sheet_dimension(
        self, request: MoveSheetDimensionReq, options: typing.List[str] = None
    ) -> typing.Tuple[MoveSheetDimensionResp, Response]:
        return self.cli.raw_request(_gen_move_sheet_dimension_req(request, options))

    def prepend_sheet_value(
        self, request: PrependSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[PrependSheetValueResp, Response]:
        return self.cli.raw_request(_gen_prepend_sheet_value_req(request, options))

    def append_sheet_value(
        self, request: AppendSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[AppendSheetValueResp, Response]:
        return self.cli.raw_request(_gen_append_sheet_value_req(request, options))

    def insert_sheet_dimension_range(
        self, request: InsertSheetDimensionRangeReq, options: typing.List[str] = None
    ) -> typing.Tuple[InsertSheetDimensionRangeResp, Response]:
        return self.cli.raw_request(
            _gen_insert_sheet_dimension_range_req(request, options)
        )

    def add_sheet_dimension_range(
        self, request: AddSheetDimensionRangeReq, options: typing.List[str] = None
    ) -> typing.Tuple[AddSheetDimensionRangeResp, Response]:
        return self.cli.raw_request(
            _gen_add_sheet_dimension_range_req(request, options)
        )

    def update_sheet_dimension_range(
        self, request: UpdateSheetDimensionRangeReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetDimensionRangeResp, Response]:
        return self.cli.raw_request(
            _gen_update_sheet_dimension_range_req(request, options)
        )

    def delete_sheet_dimension_range(
        self, request: DeleteSheetDimensionRangeReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSheetDimensionRangeResp, Response]:
        return self.cli.raw_request(
            _gen_delete_sheet_dimension_range_req(request, options)
        )

    def get_sheet_value(
        self, request: GetSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetValueResp, Response]:
        return self.cli.raw_request(_gen_get_sheet_value_req(request, options))

    def batch_get_sheet_value(
        self, request: BatchGetSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchGetSheetValueResp, Response]:
        return self.cli.raw_request(_gen_batch_get_sheet_value_req(request, options))

    def set_sheet_value(
        self, request: SetSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[SetSheetValueResp, Response]:
        return self.cli.raw_request(_gen_set_sheet_value_req(request, options))

    def batch_set_sheet_value(
        self, request: BatchSetSheetValueReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchSetSheetValueResp, Response]:
        return self.cli.raw_request(_gen_batch_set_sheet_value_req(request, options))

    def set_sheet_style(
        self, request: SetSheetStyleReq, options: typing.List[str] = None
    ) -> typing.Tuple[SetSheetStyleResp, Response]:
        return self.cli.raw_request(_gen_set_sheet_style_req(request, options))

    def batch_set_sheet_style(
        self, request: BatchSetSheetStyleReq, options: typing.List[str] = None
    ) -> typing.Tuple[BatchSetSheetStyleResp, Response]:
        return self.cli.raw_request(_gen_batch_set_sheet_style_req(request, options))

    def merge_sheet_cell(
        self, request: MergeSheetCellReq, options: typing.List[str] = None
    ) -> typing.Tuple[MergeSheetCellResp, Response]:
        return self.cli.raw_request(_gen_merge_sheet_cell_req(request, options))

    def unmerge_sheet_cell(
        self, request: UnmergeSheetCellReq, options: typing.List[str] = None
    ) -> typing.Tuple[UnmergeSheetCellResp, Response]:
        return self.cli.raw_request(_gen_unmerge_sheet_cell_req(request, options))

    def set_sheet_value_image(
        self, request: SetSheetValueImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[SetSheetValueImageResp, Response]:
        return self.cli.raw_request(_gen_set_sheet_value_image_req(request, options))

    def find_sheet(
        self, request: FindSheetReq, options: typing.List[str] = None
    ) -> typing.Tuple[FindSheetResp, Response]:
        return self.cli.raw_request(_gen_find_sheet_req(request, options))

    def replace_sheet(
        self, request: ReplaceSheetReq, options: typing.List[str] = None
    ) -> typing.Tuple[ReplaceSheetResp, Response]:
        return self.cli.raw_request(_gen_replace_sheet_req(request, options))

    def create_sheet_condition_format(
        self, request: CreateSheetConditionFormatReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSheetConditionFormatResp, Response]:
        return self.cli.raw_request(
            _gen_create_sheet_condition_format_req(request, options)
        )

    def get_sheet_condition_format(
        self, request: GetSheetConditionFormatReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetConditionFormatResp, Response]:
        return self.cli.raw_request(
            _gen_get_sheet_condition_format_req(request, options)
        )

    def update_sheet_condition_format(
        self, request: UpdateSheetConditionFormatReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetConditionFormatResp, Response]:
        return self.cli.raw_request(
            _gen_update_sheet_condition_format_req(request, options)
        )

    def delete_sheet_condition_format(
        self, request: DeleteSheetConditionFormatReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSheetConditionFormatResp, Response]:
        return self.cli.raw_request(
            _gen_delete_sheet_condition_format_req(request, options)
        )

    def create_sheet_protected_dimension(
        self,
        request: CreateSheetProtectedDimensionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateSheetProtectedDimensionResp, Response]:
        return self.cli.raw_request(
            _gen_create_sheet_protected_dimension_req(request, options)
        )

    def get_sheet_protected_dimension(
        self, request: GetSheetProtectedDimensionReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetProtectedDimensionResp, Response]:
        return self.cli.raw_request(
            _gen_get_sheet_protected_dimension_req(request, options)
        )

    def update_sheet_protected_dimension(
        self,
        request: UpdateSheetProtectedDimensionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateSheetProtectedDimensionResp, Response]:
        return self.cli.raw_request(
            _gen_update_sheet_protected_dimension_req(request, options)
        )

    def delete_sheet_protected_dimension(
        self,
        request: DeleteSheetProtectedDimensionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[DeleteSheetProtectedDimensionResp, Response]:
        return self.cli.raw_request(
            _gen_delete_sheet_protected_dimension_req(request, options)
        )

    def create_sheet_data_validation_dropdown(
        self,
        request: CreateSheetDataValidationDropdownReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateSheetDataValidationDropdownResp, Response]:
        return self.cli.raw_request(
            _gen_create_sheet_data_validation_dropdown_req(request, options)
        )

    def delete_sheet_data_validation_dropdown(
        self,
        request: DeleteSheetDataValidationDropdownReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[DeleteSheetDataValidationDropdownResp, Response]:
        return self.cli.raw_request(
            _gen_delete_sheet_data_validation_dropdown_req(request, options)
        )

    def update_sheet_data_validation_dropdown(
        self,
        request: UpdateSheetDataValidationDropdownReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateSheetDataValidationDropdownResp, Response]:
        return self.cli.raw_request(
            _gen_update_sheet_data_validation_dropdown_req(request, options)
        )

    def get_sheet_data_validation_dropdown(
        self,
        request: GetSheetDataValidationDropdownReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[GetSheetDataValidationDropdownResp, Response]:
        return self.cli.raw_request(
            _gen_get_sheet_data_validation_dropdown_req(request, options)
        )

    def create_sheet_filter(
        self, request: CreateSheetFilterReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSheetFilterResp, Response]:
        return self.cli.raw_request(_gen_create_sheet_filter_req(request, options))

    def delete_sheet_filter(
        self, request: DeleteSheetFilterReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSheetFilterResp, Response]:
        return self.cli.raw_request(_gen_delete_sheet_filter_req(request, options))

    def update_sheet_filter(
        self, request: UpdateSheetFilterReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetFilterResp, Response]:
        return self.cli.raw_request(_gen_update_sheet_filter_req(request, options))

    def get_sheet_filter(
        self, request: GetSheetFilterReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetFilterResp, Response]:
        return self.cli.raw_request(_gen_get_sheet_filter_req(request, options))

    def create_sheet_filter_view(
        self, request: CreateSheetFilterViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSheetFilterViewResp, Response]:
        return self.cli.raw_request(_gen_create_sheet_filter_view_req(request, options))

    def delete_sheet_filter_view(
        self, request: DeleteSheetFilterViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSheetFilterViewResp, Response]:
        return self.cli.raw_request(_gen_delete_sheet_filter_view_req(request, options))

    def update_sheet_filter_view(
        self, request: UpdateSheetFilterViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetFilterViewResp, Response]:
        return self.cli.raw_request(_gen_update_sheet_filter_view_req(request, options))

    def get_sheet_filter_view(
        self, request: GetSheetFilterViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetFilterViewResp, Response]:
        return self.cli.raw_request(_gen_get_sheet_filter_view_req(request, options))

    def query_sheet_filter_view(
        self, request: QuerySheetFilterViewReq, options: typing.List[str] = None
    ) -> typing.Tuple[QuerySheetFilterViewResp, Response]:
        return self.cli.raw_request(_gen_query_sheet_filter_view_req(request, options))

    def create_sheet_filter_view_condition(
        self,
        request: CreateSheetFilterViewConditionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[CreateSheetFilterViewConditionResp, Response]:
        return self.cli.raw_request(
            _gen_create_sheet_filter_view_condition_req(request, options)
        )

    def delete_sheet_filter_view_condition(
        self,
        request: DeleteSheetFilterViewConditionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[DeleteSheetFilterViewConditionResp, Response]:
        return self.cli.raw_request(
            _gen_delete_sheet_filter_view_condition_req(request, options)
        )

    def update_sheet_filter_view_condition(
        self,
        request: UpdateSheetFilterViewConditionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[UpdateSheetFilterViewConditionResp, Response]:
        return self.cli.raw_request(
            _gen_update_sheet_filter_view_condition_req(request, options)
        )

    def get_sheet_filter_view_condition(
        self, request: GetSheetFilterViewConditionReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetFilterViewConditionResp, Response]:
        return self.cli.raw_request(
            _gen_get_sheet_filter_view_condition_req(request, options)
        )

    def query_sheet_filter_view_condition(
        self,
        request: QuerySheetFilterViewConditionReq,
        options: typing.List[str] = None,
    ) -> typing.Tuple[QuerySheetFilterViewConditionResp, Response]:
        return self.cli.raw_request(
            _gen_query_sheet_filter_view_condition_req(request, options)
        )

    def create_sheet_float_image(
        self, request: CreateSheetFloatImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[CreateSheetFloatImageResp, Response]:
        return self.cli.raw_request(_gen_create_sheet_float_image_req(request, options))

    def delete_sheet_float_image(
        self, request: DeleteSheetFloatImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[DeleteSheetFloatImageResp, Response]:
        return self.cli.raw_request(_gen_delete_sheet_float_image_req(request, options))

    def update_sheet_float_image(
        self, request: UpdateSheetFloatImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[UpdateSheetFloatImageResp, Response]:
        return self.cli.raw_request(_gen_update_sheet_float_image_req(request, options))

    def get_sheet_float_image(
        self, request: GetSheetFloatImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[GetSheetFloatImageResp, Response]:
        return self.cli.raw_request(_gen_get_sheet_float_image_req(request, options))

    def query_sheet_float_image(
        self, request: QuerySheetFloatImageReq, options: typing.List[str] = None
    ) -> typing.Tuple[QuerySheetFloatImageResp, Response]:
        return self.cli.raw_request(_gen_query_sheet_float_image_req(request, options))



from pylark.lark_request import RawRequestReq, _new_method_option, Request, Response
from typing import TYPE_CHECKING, Tuple
import attr

if TYPE_CHECKING:
    from pylark.lark import Lark


@attr.s
class GetTenantAccessTokenReq(object):
    app_id = attr.ib(metadata={"req_type": "json"})  # 应用唯一标识，创建应用后获得
    app_secret = attr.ib(metadata={"req_type": "json"})  # 应用秘钥，创建应用后获得


@attr.s
class TokenExpire(object):
    token = attr.ib(default="")
    expire = attr.ib(default=0)


def _get_tenant_access_token(
    cli: "Lark",
    is_isv: bool,
    app_id: str,
    app_secret: str,
    tenant_key: str,
) -> Tuple[TokenExpire, Response]:
    # mock

    # cache

    uri = "https://open.feishu.cn/open-apis/auth/v3/tenant_access_token/internal/"
    body = {
        "app_id": app_id,
        "app_secret": app_secret,
    }
    if is_isv:
        # TODO
        app_access_token = ""
        uri = "https://open.feishu.cn/open-apis/auth/v3/tenant_access_token/"
        body = {
            "app_access_token": app_access_token,
            "tenant_key": tenant_key,
        }

    req = RawRequestReq(
        # dataclass=GetTenantAccessTokenResp,
        scope="Auth",
        api="GetTenantAccessToken",
        method="POST",
        url=uri,
        body=body,
        method_option=_new_method_option(),
    )

    data, response = Request.raw_request(cli, req)

    # set cache

    return (
        TokenExpire(
            token=data.get("tenant_access_token") or "", expire=data.get("expire") or 0
        ),
        response,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class CreateMeetingRoomRoomReq(object):
    building_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所在的建筑ID
    floor: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室所在的建筑楼层
    name: str = attr.ib(default="", metadata={"req_type": "json"})  # 会议室名称
    capacity: int = attr.ib(default=0, metadata={"req_type": "json"})  # 容量
    is_disabled: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否禁用
    custom_room_id: str = attr.ib(
        default="", metadata={"req_type": "json"}
    )  # 租户自定义会议室ID


@attr.s
class CreateMeetingRoomRoomResp(object):
    room_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 成功创建的会议室ID


def _gen_create_meeting_room_room_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=CreateMeetingRoomRoomResp,
        scope="MeetingRoom",
        api="CreateMeetingRoomRoom",
        method="POST",
        url="https://open.feishu.cn/open-apis/meeting_room/room/create",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class OpenCalenderReq(object):
    pass


@attr.s
class OpenCalenderResp(object):
    pass


def _gen_open_calender_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=OpenCalenderResp,
        scope="AppLink",
        api="OpenCalender",
        method="",
        url="https://applink.feishu.cn/client/calendar/open",
        body=request,
        method_option=_new_method_option(options),
    )



from pylark.api_service_auth_tenant_access_token_get import TokenExpire
from pylark.lark_request import RawRequestReq, _new_method_option, Request, Response
from typing import TYPE_CHECKING, Tuple
import attr

if TYPE_CHECKING:
    from pylark.lark import Lark


def _get_app_access_token(
    cli: "Lark",
    is_isv: bool,
    app_id: str,
    app_secret: str,
) -> Tuple[TokenExpire, Response]:
    # mock

    # cache

    uri = "https://open.feishu.cn/open-apis/auth/v3/app_access_token/internal/"
    app_ticket = ""
    body = {
        "app_id": app_id,
        "app_secret": app_secret,
    }
    if is_isv:
        uri = "https://open.feishu.cn/open-apis/auth/v3/app_access_token/"
        app_ticket = cli.auth.get_app_ticket()

    req = RawRequestReq(
        scope="Auth",
        api="GetAppAccessToken",
        method="POST",
        url=uri,
        body={
            "app_id": cli.app_id,
            "app_secret": cli.app_secret,
            "app_ticket": app_ticket,
        },
        method_option=_new_method_option(),
    )

    data, response = Request.raw_request(cli, req)

    # set cache

    return (
        TokenExpire(
            token=data.get("app_access_token") or "", expire=data.get("expire") or 0
        ),
        response,
    )



# Code generated by lark_sdk_gen. DO NOT EDIT.

from pylark.lark_request import RawRequestReq, _new_method_option
import attr
import typing
import io


@attr.s
class GetMessageReadUserListReqUserIDType(object):
    pass


@attr.s
class GetMessageReadUserListReq(object):
    user_id_type: GetMessageReadUserListReqUserIDType = attr.ib(
        factory=lambda: GetMessageReadUserListReqUserIDType(),
        metadata={"req_type": "query"},
    )  # 用户 ID 类型, 示例值："open_id", 可选值有: `open_id`：用户的 open id, `union_id`：用户的 union id, `user_id`：用户的 user id, 默认值: `open_id`, 当值为 `user_id`, 字段权限要求: 获取用户 userid
    page_size: int = attr.ib(
        default=0, metadata={"req_type": "query"}
    )  # 此次调用中使用的分页的大小, 示例值：20, 取值范围：`1` ～ `100`
    page_token: str = attr.ib(
        default="", metadata={"req_type": "query"}
    )  # 下一页分页的token, 示例值："GxmvlNRvP0NdQZpa7yIqf_Lv_QuBwTQ8tXkX7w-irAghVD_TvuYd1aoJ1LQph86O-XImC4X9j9FhUPhXQDvtrQ=="
    message_id: str = attr.ib(
        default="", metadata={"req_type": "path"}
    )  # 待查询的消息的ID, 示例值："om_dc13264520392913993dd051dba21dcf"


@attr.s
class GetMessageReadUserListRespItemUserIDType(object):
    pass


@attr.s
class GetMessageReadUserListRespItem(object):
    user_id_type: GetMessageReadUserListRespItemUserIDType = attr.ib(
        factory=lambda: GetMessageReadUserListRespItemUserIDType(),
        metadata={"req_type": "json"},
    )  # 用户id类型
    user_id: str = attr.ib(default="", metadata={"req_type": "json"})  # 用户id
    timestamp: str = attr.ib(default="", metadata={"req_type": "json"})  # 阅读时间


@attr.s
class GetMessageReadUserListResp(object):
    items: typing.List[GetMessageReadUserListRespItem] = attr.ib(
        factory=lambda: [], metadata={"req_type": "json"}
    )  # -
    has_more: bool = attr.ib(
        factory=lambda: bool(), metadata={"req_type": "json"}
    )  # 是否还有下一页
    page_token: str = attr.ib(default="", metadata={"req_type": "json"})  # 下一页分页的token


def _gen_get_message_read_user_list_req(request, options) -> RawRequestReq:
    return RawRequestReq(
        dataclass=GetMessageReadUserListResp,
        scope="Message",
        api="GetMessageReadUserList",
        method="GET",
        url="https://open.feishu.cn/open-apis/im/v1/messages/:message_id/read_users",
        body=request,
        method_option=_new_method_option(options),
        need_tenant_access_token=True,
    )
